********************************************************************************************************
*  Syntax file to accompany 'Work, Attitudes & Spending' household surveys:  	   *
*  No need to run this file again (you can read it, to see how variables are derived).	   *
********************************************************************************************************.
* Default value labels:  use these for all numeric variables.  They are used in BHPS, except -6.
*-1"don't know" -2"refused" -6"not asked in this survey" -8"inapplicable" -9"missing/wild [e.g. no answer]".
*-7"proxy respondent": I never use it.  -3 & -4 specific to a particular variable, e.g. too young for school.


*@ INTERVIEW DETAILS.

* Create a unique ID number for each household.  Ignore ID:  it's just temporary.
if (INT_year= 1992)		surveyN = 1.
if (INT_year= 1994)		surveyN = 2.
if (INT_year= 1997)		surveyN = 3.
if (INT_year= 2000)		surveyN = 4.
if (INT_year= 2001)		surveyN = 5.
if (INT_year= 2002 & live_cit>  6)	surveyN = 6.
if (INT_year= 2002 & live_cit<10)	surveyN = 7.
if (INT_year= 2003)		surveyN = 8.
if (INT_year= 2004)		surveyN = 9.
if (INT_year= 2005)		surveyN = 10.
if (survey    ='2005-6 Egypt')	surveyN = 11.
if (INT_year= 2007)		surveyN = 12.
if (INT_year= 2008)		surveyN = 13.
if (INT_year= 2009)		surveyN = 14.
if (INT_year= 2011)		surveyN = 15.
if (INT_year= 2012)		surveyN = 16.
if (INT_year= 2017)		surveyN = 17.
var label	                    		surveyN  'Survey number'.

compute						ID = 1.			/* Create ID, to ensure consecutive numbers.
exec.
if 				(surveyN = lag(surveyN))	ID = lag(ID)   + 1.
compute			IDnum=	(surveyN*100000)   +	ID.
var label 			IDnum  'Household identification number'.


var lab	temperat      	'Temperature at the time & place of interview (measured by thermometer)'.
var lab 	thermometer 	'Type of thermometer used, to measure the temperature'.
val lab	 thermometer  0 'Weather genius'  1 'Magna-temp'.		/* 'Weather genius' has a digital display with 1 decimal place; 'Magna-temp' only whole numbers.


val label 		INT_mnth  1"January" 2"February" 3"March" 4"April" 5"May" 6"June" 7"July" 8"August" 9"September" 10"October" 11"November" 12"December".
var label		INT_year 	'Year of interview'.
var label		INT_mnth 	'Month of interview'.
var label		INT_day 	'Day of month of interview'.
var label		INT_time 	'Time of day (nearest hour) the interview ended'.

var label		INTplace	'Place where interview took place'.
val label		INTplace  1 'inside the home'  2 'on the doorstep'  3 'somewhere else'.

var label 		INT_CHEK 	'Was interview checked by a (market research organisation) supervisor?'.
val label 		INT_CHEK 	0"not checked"	1"accompanied by supervisor"	2"backchecked"
			              	3"saw form"  	4"accompanied & backchecked"	5"accompanied & saw form"
					6"saw form & backchecked"	7"accompanied, saw form & backchecked".

* First, a simplified version of INT_PRES (INT_PRES not recorded in Indonesia, but PRESENT was recorded).
if (INT_PRES>1)	INTpresn = 1.
if (INT_PRES=1)	INTpresn = 0.
var label		INTpresn 'Was anyone (exept respondent) present at interview?'.
val label		INTpresn 0'respondent only' 1'1 or more others present'.
var label 		INT_PRES 'If anyone except respondent present at interview, who?'.
val label 		INT_PRES	1'respondent only'	2'spouse'		3'other adult(s)'		4'child(ren)'
	           				5'spouse and other'  	6'spouse & child(ren)'  	7'children/other adult'	8'spouse/child/other'.

var label						 	INT_CODE 'Code for interviewer'.

var label					     	INTfemal 'Gender of interviewer'.
val label				 	   		INTfemal 0   'male interviewer'  1'female interviewer'  0.5'male & female interviewers'.

var label		SEX 'Gender of respondent'.
val label		SEX 0'male' 1'female'.


* p1_relat etc won't report as HoH if p1 is respondent.
value labels 	fem_HEAD  	    0'male' 1'female'.
var label      		fem_HEAD	"Female headed household".

var lab			  resp_ORD	'Respondent mentioned himself/herself 1st/2nd/etc'.
var lab			 spou_ORD	'Respondent mentioned his/her spouse 1st/2nd/etc'.
var lab			CWE_ORD	'Respondent mentioned Chief Wage Earner 1st/2nd/etc'.
val label			  resp_ORD
			   1"mentioned self 1st" 	  2"mentioned self 2nd"	  3"mentioned self 3rd"
			   4"mentioned self 4th"	  5"mentioned self 5th"  	  6"mentioned self 6th"
			   7"mentioned self 7th"	  8"mentioned self 8th"	  9"mentioned self 9th"
			 10"mentioned self 10th"	11"mentioned self 11th"	12"mentioned self 12th"
			 13"mentioned self 13th"	14"mentioned self 14th"	15"mentioned self 15th"
			 16"mentioned self 16th"	17"mentioned self 17th".
val label			spou_ORD 
			1"mentioned spouse 1st"	  2"mentioned spouse 2nd"    3"mentioned spouse 3rd"
			4"mentioned spouse 4th"  5"mentioned spouse 5th"     6"mentioned spouse 6th"
			7"mentioned spouse 7th"  8"mentioned spouse 8th"     9"mentioned spouse 9th"
		        10"mentioned spouse 10th"	11"mentioned spouse 11th" 12"mentioned spouse 12th"
		        13"mentioned spouse 13th"	14"mentioned spouse 14th" 15"mentioned spouse 15th".
val label			CWE_ORD 
			1"mentioned CWE 1st"	  2"mentioned CWE 2nd"    3"mentioned CWE 3rd"
			4"mentioned CWE 4th"	  5"mentioned CWE 5th"     6"mentioned CWE 6th"
			7"mentioned CWE 7th"	  8"mentioned CWE 8th"     9"mentioned CWE 9th"
		          10"mentioned CWE 10th"	11"mentioned CWE 11th" 12"mentioned CWE 12th"
		          13"mentioned CWE 13th"	14"mentioned CWE 14th" 15"mentioned CWE 15th".

*cros	p1_relat by survey.					/* To identify which surveys we can reliably for wifBefor & husBefor.
*if (survey='1992 India')		resp_ORD 		= -9.		/* The respondent is USUALLY first in 1992 India;   so wifBefor & husBefor unreliable.
*if (survey='1992 India')		spou_ORD 		= -9.
*if (survey='1994 Brazil')		resp_ORD 		= -9.		/* The respondent is USUALLY first in 1994 Brazil;  so wifBefor & husBefor unreliable.
*if (survey='1994 Brazil')		spou_ORD 		= -9.
*if (survey='1997 India')		resp_ORD 		= -9.		/* The respondent is USUALLY first in 1997 India;   so wifBefor & husBefor unreliable.
*if (survey='1997 India')		spou_ORD 		= -9.
*if (survey='2002 India')		resp_ORD 		= -9.		/* The respondent is USUALLY first in 2002 India;   so wifBefor & husBefor unreliable.
*if (survey='2002 India')		spou_ORD 		= -9.
*if (survey='2003 Nigeria')	resp_ORD 		= -9.		/* The respondent is USUALLY first in 2003 Nigeria; so wifBefor & husBefor unreliable.
*if (survey='2003 Nigeria')	spou_ORD 		= -9.
if (survey='2004 Kenya')		resp_ORD 		= -9.		/* The respondent is ALWAYS first in 2004 Kenya;  so wifBefor & husBefor unhelpful.
if (survey='2004 Kenya')		spou_ORD 		= -9.
*if (survey='2005 Nigeria')	resp_ORD 		= -9.		/* The respondent is USUALLY first in 2005 Nigeria; so wifBefor & husBefor unreliable.
*if (survey='2005 Nigeria')	spou_ORD 		= -9.
if  (married=0 or (married>2 & married<7))		HUSbefor 	= -4.
if  (married=0 or (married>2 & married<7))		WIFbefor 	= -4.
recode				resp_ORD  spou_ORD	 ( -9 = sysmis).
if  (sex=1 & 			resp_ORD>spou_ORD)	HUSbefor 	=  1.
if  (sex=1 & 			resp_ORD<spou_ORD)	HUSbefor 	=  0.
if  (sex=0 & 			resp_ORD>spou_ORD)	WIFbefor 	=  1.
if  (sex=0 & 			resp_ORD<spou_ORD)	WIFbefor 	=  0.
var label 					HUSbefor 	'[female resp] discussed husband before herself'.
var label 					WIFbefor 	   '[male resp] discussed his wife before himself'.
val label 					HUSbefor	0"mentioned self first" 1"mentioned husb first"  -4"respondent unmarried".
val label 					WIFbefor 	0"mentioned self first" 1"mentioned wife first"   -4"respondent unmarried".
*if (survey='1992 India')				HUSbefor		= -9.
*if (survey='1992 India')				WIFbefor		= -9.
*if (survey='1994 Brazil')				HUSbefor		= -9.
*if (survey='1994 Brazil')				WIFbefor		= -9.
*if (survey='1997 India')				HUSbefor		= -9.
*if (survey='1997 India')				WIFbefor		= -9.
if (survey='2000 S. Africa')				HUSbefor	= -9.  /* Markinor Pty didn't send me raw data on hhold members, for 2000 S.Africa.
if (survey='2000 S. Africa')				WIFbefor	= -9.
*if (survey='2002 India')				HUSbefor		= -9.
*if (survey='2002 India')				WIFbefor		= -9.
*if (survey='2003 Nigeria')				HUSbefor	= -9.
*if (survey='2003 Nigeria')				WIFbefor	= -9.
if (survey='2004 Kenya')				HUSbefor		= -9.
if (survey='2004 Kenya')				WIFbefor		= -9.
*if (survey='2005 Nigeria')				HUSbefor	= -9.
*if (survey='2005 Nigeria')				WIFbefor	= -9.
recode					HUSbefor WIFbefor	 ( -9 = sysmis).
*cros					HUSbefor WIFbefor 	by survey.

*   I could also work out 	resp_HoH for other years (currently only in SA2000);  how to identify HoH?.
var labels		resp_HoH	"If respondent is the head-of-household".
value labels                	resp_HoH	1"Respondent is the HoH" 0"Respondent is spouse of HoH"		-4"Respondent is neither HoH or spouse".
*Could create resp_HoH for other years(currently only in SA2000); how to identify HoH?.
*crosstab		resp_HoH by survey.


*@ BIRTHPLACE OF RESPONDENT.
* See file 'BORN and LIVEvariables.sps'.


*@ DEMOGRAPHICS / EDUCATION.
var label 	MARRIED "Respondent's marital status".
val label 	MARRIED	0"unmarried (singl/widow/div/sep)" 1"married" 2"cohabiting" 3"single" 4"widowed" 5"divorced" 6"separated" 7"wife of polygamous husband".

*cros			 EDUC by survey.
recode			 EDUC (sysmis = -77).
missing values			 EDUC ( -88 ).
if 			(EDUC<0  and  LITERATE=0)	EDUC=0.	/* Respondent may not want to admit they've no education. This adds 2 cases.
*cros			 EDUC by survey.
*cros			 EDUC by literate	by survey.		/* Some cases (in Nigeria) claim respondent is in college, but is not literate ...
*if	(literate=0 & 	EDUC>40)	 EDUC = -9.			/* ...implausible, so could set EDUC to missing; but maybe literate is incorrect?.

recode	                                 	educ_hus educ_wif (sysmis = -77).		/* educ_hus & educ_wif are known for India 1992 (at least).
if  (educ_wif  = -77 & sex=0)  	educ_wif      =	 EDUCspou.
if  (educ_wif  = -77 & sex=1)  	educ_wif      =	 EDUC.
if  (educ_hus = -77 & sex=0)  	educ_hus    =	 EDUC.
if  (educ_hus = -77 & sex=1)  	educ_hus    =	 EDUCspou.
recode		                                 educ_hus educ_wif (-77 = sysmis).
var label	EDUC           	"Education level of respondent".
var label	EDUCspou    	"Education level of spouse of respondent".
var label       	educ_hus	"Education level of husband of respondent".
var label   	    	educ_wif 	"Education level of wife of respondent".
var label	EDUC_CWE 	"Education level of Chief Wage Earner".
val label	EDUC, EDUCspou, educ_hus, educ_wif, EDUC_cwe
	  0 "no school/illiterate"
	10 "school up to 4 years"      		20 "over 4 years primary school"		30 "primary school completed, some secondary"
	40 "secondary school, incomplete/preparatory school" 55 "matric/Secondary School Cert/O or A-level"	57 "artisan's certificate"
	65 "college not graduate (eg technical)"	72 "college: diploma/secretarial qual"		75 "higher college (Technikon) diploma/degree"
	77 "incomplete degree"			80 "graduate/above, general"		90 "postgrad (e.g. MA); graduate professional"   100 "PhD"
	59 "other"		-2 "not disclosed"	 -3 "too young to be at school".	/* My scale:  0=no school   to  100=20 years (i.e. PhD).
* Educ=30 (formerly =35) should be equivalent to '5 to 9 years of educ' in IMRB 1997 & 2002.
* In Indonesia,'college diploma' means 'college diploma D1/D2'; 'higher college diploma' is 'college diploma D3'.
* For Indonesia, rs09 indicates if study completed - could use this to make more detailed educ variable.

* Make WAS comparable to DHS, in having a variable to estimate the number of years in education.  I drop 59 (although this reduces the sample-size).
if (LIVEctry<>'CM')	educY 	= educ.			/* For Cameroon 2009 survey, respondents reported (approx) exact number of years in education.
if (LIVEctry<>'CM')	educYhus 	= educ_hus.
if (LIVEctry<>'CM')	educYwif 	= educ_wif.
var label      		educY	"Number of years in education:  respondent".
var label      		educYhus 	"Number of years in education:  husband /male respondent".
var label     		 educYwif 	"Number of years in education:  wife /female respondent".
recode		         educYwif	   educYhus   educY   (0=0)(10=3)(20=5)(30=7)(35=7)(40=8)(55=11)(65=12)(72=13)(75=14)(77=15)(80=16)(90=17)(100=20)(59=sysmis).
* The above recodes are arbitrary, and are based on Cameroon. 
* Ideally, should go back to each WAS survey and change the above line to an appropriate version for that questionnaire.

if (LIVEctry = 'CM' & sex=0)	educYhus 	= EDUCy.
if (LIVEctry = 'CM' & sex=1)	educYwif  	= EDUCy.
if (LIVEctry = 'CM' & sex=1)	educYhus 	= EDUCspouy.
if (LIVEctry = 'CM' & sex=0)	educYwif  	 = EDUCspouy.

recode		             EDUC, educY, educYwif, educYhus ( -77, 98 =sysmis).
missing values		 EDUC, educY, educYwif, educYhus (   -9 thru -1).


* Languages:  I don't put the next block of 30 lines in 'language and ethnic vars.sps', because that files is also used for DHS and Afrobarometer.
var label	L_Englis	'Know language: English'.
var label	L_Afrika 	'Know language: Afrikaans'.			/* first of South African languages.
var label	L_Zulu	'Know language: Zulu'.
var label	L_Xhosa 	'Know language: Xhosa'.
var label	L_NSotho 	'Know language: N. Sotho'.
var label	L_SSotho 	'Know language: S. Sotho'.
var label	L_Tswana 	'Know language: Tswana'.
var label	L_Tsonga 	'Know language: Tsonga/Shangaan'.
var label	L_Venda 	'Know language: Venda'.
var label	L_Swazi 	'Know language: Swazi'.
var label	L_Ndebel 	'Know language: Ndebele'.			/* last of South African languages.
var label	L_Hausa 	'Know language: Hausa'.			/* first of Nigerian languages.
var label	L_Igbo	'Know language: Igbo'.
var label	L_Yoruba 	'Know language: Yoruba'.
var label	L_Fulani 	'Know language: Fulani'.
var label	L_Edo	'Know language: Edo'.
var label	L_Tiv 	'Know language: Tiv'.
var label	L_Nupe 	'Know language: Nupe'.
var label	L_Urhobo 	'Know language: Urhobo'.			/* last of Nigerian languages.
var label	L_other 	'Know language: other(s)'.
val lab	L_Englis 	L_Afrika 	L_Zulu 	L_Xhosa 	L_NSotho 	L_SSotho
	L_Tswana	L_Tsonga 	L_Venda	L_Swazi 	L_Ndebel 
	L_Hausa  	L_Igbo  	L_Yoruba  	L_Fulani  	L_Edo  	L_Tiv  	L_Nupe  	L_Urhobo  	L_other
		0"can't read this langauge"	1"can read this language"	2"understand it, but can't read it"	3"can both read & understand it".
*freq	L_Englis.

* These value labels are already in the WAS surveys which have literate (ZA 2000, NG 2003, and NG 2005).
*var label        	literate "Respondent's literacy".  /* DHS use all labels below;  WAS only uses 0 or 2.
*val label        	literate  0 'cannot read'  1'able to read parts of sentence'  2 'able to read whole sentence'
				 -3 'no card with required language' -4 'blind/visually impaired' -9 "missing data".
*missing values     	literate (-9 thru -1).


*@ WORK / SOCIAL CLASS.
*EDUC_CWE and JOB_CWE combined into one summary measure, by IMRB  (CWE_CODE): .
*var label CWE_CODE 'IMRB classification of Chief Wage Earner'.
*cros 	 CWE_code by survey. /* zzz these next lines may be already run, in each survey.
if 	(CWE_code = 'A1')	IMRBclas = 1.
if 	(CWE_code = 'A2')	IMRBclas = 2.
if 	(CWE_code = 'B1')	IMRBclas = 3.
if 	(CWE_code = 'B2')	IMRBclas = 4.
if 	(CWE_code = 'C ')	IMRBclas = 5.
if 	(CWE_code = 'D ')	IMRBclas = 6.
if 	(CWE_code = 'E1')	IMRBclas = 7.
if 	(CWE_code = 'E2')	IMRBclas = 8.
*val lab			IMRBclas 1 'A1'  2 'A2'  3 'B1'  4 'B2'  5 'C'  6 'D'  7 'E1'  8 'E2'.
val lab		  	IMRBclas 1 'A1'  2 'A2'  3 'B1'  4 'B2'  5 'C'  6 'D'  7 'E1'  8 'E2'	1.5 'AB'  5.1 'C1'  5.2 'C2'.
* The last 3 values are for Cameroon;  this is Cible, not IMRB.
var lab		  IMRBclas "Class of household, based on head-of-household's job & education (IMRB and Cible)".
*cros 	   		IMRBclas by survey.
* Details, from IMRB India 2002-2007 questionnaires:					 EDUCATION
*  OCCUPATION		ILLITERATE	 SCHOOL 	 SCHOOL	       SSC/	COLLEGE	    GRAD/	    GRAD/
*				UP TO 4 YRS	  5-9 YRS	       HSC	NOT GRAD	POSTGRAD	   POSTGRAD
*								     (GEN)	   (PROF)
*			1	2	3	4	5	6	7	
*			 ----------------------------------------------------------------------------------------------------------------------------------------	
* Unskilled			E2	E2	E1	D	D	D	D
* Skilled worker		E2	E1	D	C	C	B2	B2
* Petty trader			E2	D	D	C	C	B2	B2
* Shop owner			D	D	C	B2	B1	A2	A2
* Businessmen: *  no employees	D	C	B2	B1	A2	A2	A1
*	  * 1-9 employees	C	B2	B2	B1	A2	A1	A1
*	  *10+ employees	B1	B1	A2	A2	A1	A1	A1
* self-employed professional		D	D	D	B2	B1	A2	A1
* clerical/sales			D	D	D	C	B2	B1	B1
* supervisory level		D	D	C	C	B2	B1	A2
* officer/exec:  junior		C	C	C	B2	B1	A2	A2
* officer/exec:  middle/senior		B1	B1	B1	B1	A2	A1	A1

if      (sex=0)	job_hus  =	job.
if      (sex=1)	job_hus  =	job_spou.
if      (sex=1)	job_wif  =	job.
if      (sex=0)	job_wif  =	job_spou.
var label	job      	"Job code of respondent".
var label	job_spou 	"Job code of spouse of respondent".
var label	job_wif 	"Job code of resp's wife, or respondent if female".
var label	job_hus 	"Job code of husband of resp, or resp if male".
var label	job_CWE  	"Job of Chief Wage Earner".
val label		job_CWE, job, job_spou, job_hus, job_wif
				98 "mid/senior officer/executive",   		95 "officer/executive",
				92 "junior officer/executive"
				86 "manager: 10+ employees",		84 "manager:1-9 employees"	
				83 "manager",				82 "manager:  0 employees",
				75 "professional (often self-employed)",		65 "self-employed: unspecified",
				59 "shop owner",			51 "petty trader/hawker",
				45 "supervisory",	40 "civil servant",	35 "clerical/sales",	30 "traditional doctor",
				29 "manual: skilled",	28 "farmer",		27 "employed: unspecified",
				25 "manual: unspecified",			24 "manual: semi-skilled",
				21 "manual: unskilled", 	20 "farm worker",   18 'clergy',	15 "student",
				  9 "housewife: was employed",		  8 "housewife: dk if ever employed",
				  7 "housewife: never employed",		  5 "unemployed: was employed",
				  4 "unemployed: never employed",		  3 "unemployed: no details",
			       	  2 "unemployed: seeking work",		  1 "unemployed: not seeking work",
				  0 "retired",				 -3 "too young to be employed",
				 -2 "not disclosed",	    -1"don't know",	 -9 "missing/no answer/wild".
* NOTE: The above value labels are also used for  p1_job, p2_job, etc ('derive HH vars from P1 etc.sps').
* For Indonesia 2001 & 2002, associate professionals included in 45;  maybe should be a new category.

recode	         job	       job_resp  (sysmis = -77).
*cros	             job	by job_resp.				/* Cameroon only;  this is a fairly good match, so delete variable job_resp.
if	(job= -77)	job  =   job_resp.
recode	         job        job_resp  ( -77 = sysmis).

var label			        live_cit 'City where respondent lives'.
*crosstab	paid_hus paid_wif by live_cit.
* WARNING:   in Patna 2002, the hours of paid work is small (often 0) for both husband & wife. This isn't a data processing error:  they're written (very clearly) on paper. 
* 	   Maybe the question was mis-translated in Patna.  My guess: maybe work hours are per day (not per week) in Patna?  I tried this, but husband hours still low.
* 	   Maybe days per week in Patna? (most, but not all, cases are under 8). If so, how many hours per day: is 7 about right?.
*if (		 paid_hus>0) 	test_hus	= paid_hus.
*if (		 paid_wif >0)	test_wif	= paid_wif.
*if (live_cit=5 & paid_hus>0)		test_hus	= paid_hus*7. /*Assume people work 7 days per week,or 7 hours per day.
*if (live_cit=5 & paid_wif >0)		test_wif 	= paid_wif *7.
*breakdown			test_hus,test_wif by live_cit.
* The above code seems to almost work.
*if (live_cit=5 & paid_hus>0) 	paid_hus	= paid_hus*7.
*if (live_cit=5 & paid_wif >0) 	paid_wif 	= paid_wif *7.
* But do another check: .
*cros paid_hus by live_cit by job_hus. /*(job_hus calculated in 'derive HH vars from p1 etc.sps' & 'derive_v.sps'): many in Patna report paid_hus=0, 
* when they do have a paid job - so paid_hus data is not safe to use.
if (live_cit=5)	paid_hus	= -6.	/* Set to missing  (seems a waste of data:  e.g. zero hours=unemployed).
if (live_cit=5)	paid_wif 	= -6.
*crosstab	paid_hus paid_wif by live_cit.	/*The next few lines set paid_hus & paid_wif to zero or missing.

* In Nigeria (at least), there'e a lot of missing earnings data, and few earn zero:  clarify using job_hus, job_wif.
*breakdown earn_hus,paid_hus, earn_wif,paid_wif by workst.
*  PAID_hus, PAID_wif  have far less missing data,  than 	EARN_hus  &	EARN_wif.
* Assume husb has no job if 		PAID_hus=	0   & 	EARN_hus missing.
* Assume wife 	 has no job if 		PAID_wif =	0   & 	EARN_wif  missing.
recode						EARN_hus,	EARN_wif (	         sysmis= -90).
if (EARN_hus<0	& PAID_hus	= 0)			EARN_hus			= 0.
if (EARN_wif <0	& PAID_wif	= 0)			EARN_wif	= 0.
if (EARN_hus<0	& job_hus  >	-1 &  job_hus< 21)	EARN_hus			= 0.
if (EARN_wif <0	& job_wif   >	-1 &  job_wif	 < 21)	EARN_wif	= 0.
recode						EARN_hus,	EARN_wif (	-90 = sysmis).
if 	 (survey='1992 India')				EARN_hus 	=	-99.		/* All valid cases are zero;  exclude them.
if 	 (survey='1992 India')				EARN_wif   	=	-99.		/* All valid cases are zero;  exclude them.
if 	 (survey='2000 S. Africa' & LIVEurbn>1)		EARN_hus 	=	-99.		/* All valid cases are zero;  exclude them.
if 	 (survey='2000 S. Africa' & LIVEurbn>1)		EARN_wif   	=	-99.		/* All valid cases are zero;  exclude them.
recode						EARN_hus 	EARN_wif (	-99 = sysmis).
breakd						EARN_hus 	EARN_wif  by survey /cells mean.

* Now, deal with missing time-use data.
if (PAID_hus< 0	&  job_hus  >	-1 &  job_hus	< 21)		PAID_hus			= 0.
if (PAID_wif < 0	&  job_wif   >	-1 &  job_wif	< 21)				PAID_wif	= 0.

* For Indonesia, don't change the data (resp & spouse info available separately; I assume this is more reliable).
*if ( (live_cit<41 or live_cit>44)  &	sex=0)			paidResp = paid_hus.
*if ( (live_cit<41 or live_cit>44)  &	sex=1)			paidResp = paid_wif.
*if ( (live_cit<41 or live_cit>44)  &	sex=1 & married=1)	paidSpou = paid_hus.
*if ( (live_cit<41 or live_cit>44)  &	sex=0 & married=1)	paidSpou = paid_wif.
* Above 4 lines are in 'derive data about the respondent.SPS', for all surveys.  What about [married=7]?.

* In future WAS surveys: make sure all time-use variables (cooking, etc) hours per week, not minutes per day.
var label				 	PAID_HUS	"Hours of paid work (per week): self/husband".
var label 					PAID_WIF	"Hours of paid work (per week): self/wife".
var label				 	sEmp_HUS	"Hours of self-employment (per week): self/husband".
var label 					sEmp_WIF	"Hours of self-employment (per week): self/wife".
* Note:			don't keep {washResp,washSpou}:  	just keep {wash_HUS, wash_WIF}  (& other time-use vars).
* for consistency, 	don't keep {  paidResp,  paidSpou}:  	just keep { paid_HUS,   paid_WIF}.
* If users want to find paidResp etc, they can run 'derive data about the respondent.SPS'.

* For sa2000, WORKST includes information on FT vs PT job - very different to paid_hus/paid_wif.
* I drop workst;  it could be kept - but no equivalent for other years. Unclear what 'full-time' means (subjective).
*if (isfemale=0)	 hours=paid_hus.
*if (isfemale=1)	 hours=paid_wif.
*crosstab	 hours          by workst.

missing value 		WHYnoJOB (' ').
var label 		WHYnoJOB '[IF NOT EMPLOYED] Why are you not employed?'.
val label		 	WHYnoJOB '1' "baby/child"			'2' "other unspecified"
				       '3' "after marriage"			'4' "family won't allow"
				       '5' "family commitment/no time"	'6' "pay would be low"
				       '7' "prefer to mind kids"      		'8' "ill/retired/too old"
				       '9' "can't get a job"			'0' "no need to work"
				       'A' "husband won't allow"		'B' "no maid/can't get maid"
				       'C' "housewife"			'D' "student"
				       'E' "hoping to buy a business"	'F' "religion(women born to mind kids)"
				       'G' "minding sick mother".

if   (CLASS_WK >-1)	CLASS = 0.
if   (CLASS_WK = 1)	CLASS = 1.
if   (CLASS_SE  = 1)	CLASS = 2.
if   (CLASS_MI   = 1)	CLASS = 3.
var label		CLASS	'Highest social class of all HH members'.
val label		CLASS				0"student/not employed",1"working-class",	2"self-employed trader",	3"middle-class".
var label 		CLASS_WK 	'Is any household member working-class?'.
val label		CLASS_WK				0"not working-class" 	1"working-class member".
var label		CLASS_MI 	'Is any household member middle-class?'.
val label		CLASS_MI				0"not middle-class"	1"middle-class member".
var label		CLASS_SE 	'Is any household member self-employed?'.
val label		CLASS_SE				0"no trader in hhold"	1"s-emp trader in hhold".


*@ TIME-USE.
* COOKING is split into 2 vars are in Brazil & Indonesia, but not in other surveys.
if (COOKpHUS >-1  & COOKcHUS>-1)		 COOK_HUS	= COOKpHUS	+ COOKcHUS.
if (COOKpWIF >-1  & COOKcWIF>-1)		 COOK_WIF	= COOKpWIF	+ COOKcWIF.
*rs94 (only) had 2 cooking questions: COOKp & COOKc.	 COOK_HUS	= COOKpHUS	+ COOKcHUS approx.
missing values	          choreHus  laundHus  cook_hus  	wash_hus  	    	shop_hus   mind_hus (-9 thru -1).
missing values	          choreWif  laundWif   cook_wif  	wash_wif  	    	shop_wif     mind_wif  (-9 thru -1).

*if  (INT_year >1992)			wash_HUS	= laundHUS	+ cleanHUS.		/* For comparability with bm92.
*if  (INT_year >1992)			wash_WIF	= laundWIF	+ cleanWIF.		/* For comparability with bm92.
if  (INT_year >1992 & LIVEctry<>'ID')			wash_HUS	= laundHUS	+ cleanHUS.		/* For comparability with bm92.
if  (INT_year >1992 & LIVEctry<>'ID')			wash_WIF	 = laundWIF 	+ cleanWIF.		/* For comparability with bm92.

breakd		                                                        cook_hus   	wash_hus    clothhus     	shop_hus    mind_hus by survey/cells mean.
compute	                            	hwrk_hus = cook_hus +	wash_hus	                     + 	shop_hus + mind_hus.	/* For most surveys:  exceptions listed below.
if  (survey='1992 India')	hwrk_hus = cook_hus +	wash_hus.				/* shop_hus & mind_hus aren't in bm92; could remove this line.
if  (survey='1997 India')	hwrk_hus = cook_hus +	wash_hus + clothhus +	shop_hus+ mind_hus.	/* clothhus:  India only.
if  (survey='2002 India')	hwrk_hus = cook_hus +	wash_hus + clothhus +	shop_hus+ mind_hus.	/* clothhus:  India only.
if  (survey='2007 India')	hwrk_hus = cook_hus +	wash_hus + clothhus +	shop_hus+ mind_hus.	/* clothhus:  India only.
if  (survey='2012 India')	hwrk_hus = cook_hus +	wash_hus + clothhus +	shop_hus+ mind_hus.	/* clothhus:  India only.
if  (survey='2017 India')	hwrk_hus = cook_hus +	wash_hus + clothhus +	shop_hus+ mind_hus.	/* clothhus:  India only.
*if(survey='2002 Indonesia')	hwrk_hus = cook_hus +	wash_hus	          + 	shop_hus.		/* ID 2002:  mind_hus unavailable (data-processing problem).
if  (survey='1994 Brazil')	hwrk_hus = cook_hus +   laundhus	          + 	shop_hus+ mind_hus.	/* BR 1994: included laundHus but not cleanHus.
if  (survey='2005-6 Egypt')	hwrk_hus =           choreHus 		          + 	shop_hus+ mind_hus. /* choreHus includes various types of housework.
*.
*breakd                                                        cook_wif     	 wash_wif	   clothwif       	shop_wif   mind_wif  by survey /cells mean.
compute		                            hwrk_wif  = cook_wif   +	wash_wif	                        + 	shop_wif + mind_wif.	/* For most surveys:  exceptions listed below.
if  (survey='1992 India')	hwrk_wif  = cook_wif   +	wash_wif.				/* shop_wif & mind_wif aren't in bm92; could remove this line.
if  (survey='1997 India')	hwrk_wif  = cook_wif   +	wash_wif  + clothwif   + 	shop_wif + mind_wif.	/* clothwif:  India only.
if  (survey='2002 India')	hwrk_wif  = cook_wif   +	wash_wif  + clothwif   + 	shop_wif + mind_wif.	/* clothwif:  India only.
if  (survey='2007 India')	hwrk_wif  = cook_wif   +	wash_wif  + clothwif   + 	shop_wif + mind_wif.	/* clothwif:  India only.
if  (survey='2012 India')	hwrk_wif  = cook_wif   +	wash_wif  + clothwif   + 	shop_wif + mind_wif.	/* clothwif:  India only.
if  (survey='2017 India')	hwrk_wif  = cook_wif   +	wash_wif  + clothwif   + 	shop_wif + mind_wif.	/* clothwif:  India only.
*if(survey='2002 Indonesia')	hwrk_wif  = cook_wif   +	wash_wif	          + 	shop_wif.		/* ID 2002:  mind_wif unavailable (data-processing problem).
if  (survey='1994 Brazil')	hwrk_wif  = cook_wif   +    laundwif	          + 	shop_wif + mind_wif.	/* BR 1994: included laundwif but not cleanwif.
if  (survey='2005-6 Egypt')	hwrk_wif  =           choreWif 		          + 	shop_wif + mind_wif. /* choreWif includes various types of housework.
* Housework time in India 1992 is much lower than later India surveys, because fewer time-use questions asked in 1992;  could make hwkr_hus&hwrk_wif missing in 1992.

* It's not clear if hwrk should include shopping or childcare.  Calculate another variable, which excludes both;  call it choreHus & choreWif (already in WAS EG).
if  (survey<>'2005-6 Egypt') chorehus = cook_hus  +	wash_hus.	                                                      /* For most surveys:  exceptions listed below.
if  (survey='1997 India')	       chorehus = cook_hus +	wash_hus + clothhus.                                        /* clothhus:  India only.
if  (survey='2002 India')        chorehus = cook_hus +	wash_hus + clothhus.                                        /* clothhus:  India only.
if  (survey='2007 India')        chorehus = cook_hus +	wash_hus + clothhus.                                        /* clothhus:  India only.
if  (survey='2012 India')        chorehus = cook_hus +	wash_hus + clothhus.                                        /* clothhus:  India only.
if  (survey='2017 India')        chorehus = cook_hus +	wash_hus + clothhus.                                        /* clothhus:  India only.
if  (survey='1994 Brazil')	     chorehus = cook_hus +   laundhus.                                                    	/* BR 1994: included laundHus but not cleanHus.
*.
if  (survey<>'2005-6 Egypt') chorewif  = cook_wif   +	wash_wif.                                                 	/* For most surveys:  exceptions listed below.
if  (survey='1997 India')        chorewif  = cook_wif   +	wash_wif  + clothwif.                                      /* clothwif:  India only.
if  (survey='2002 India')        chorewif  = cook_wif   +	wash_wif  + clothwif.                                     	/* clothwif:  India only.
if  (survey='2007 India')        chorewif  = cook_wif   +	wash_wif  + clothwif.                                     	/* clothwif:  India only.
if  (survey='2012 India')        chorewif  = cook_wif   +	wash_wif  + clothwif.                                     	/* clothwif:  India only.
if  (survey='2017 India')        chorewif  = cook_wif   +	wash_wif  + clothwif.                                     	/* clothwif:  India only.
if  (survey='1994 Brazil')	      chorewif  = cook_wif   +    laundwif.				/* BR 1994: included laundwif but not cleanwif.
* Housework time in India 1992 is much lower than later India surveys, because fewer time-use questions asked in 1992;  could make chorehus & chorewif missing in 1992.

*  Could exclude mind_hus & mind_wif from hwrk_hus & hwrk_wif, on the grounds that childminding can be done at the same time as other jobs.
var label		hwrk_HUS    	'hours spent cooking/cleaning/laundry/shopping/childcare (per week): self/husband'.
var label		hwrk_WIF     	'hours spent cooking/cleaning/laundry/shopping/childcare (per week): self/wife'.
var label		choreHUS    	'hours spent cooking/cleaning/laundry (per week): self/husband'.
var label		choreWIF    	'hours spent cooking/cleaning/laundry (per week): self/wife'.
var label		COOKpHUS 	'hours preparing food before cooking (per week): self/husband'.
var label		COOKpWIF 	'hours preparing food before cooking (per week): self/wife'.
var label		COOKcHUS 	'hours cooking,excluding food preparation(per week): self/husb'.
var label		COOKcWIF 	'hours cooking,excluding food preparation(per week): self/wife'.
var label		COOK_HUS 	'hours spent cooking (per week): self/husband'.
var label		COOK_WIF 	'hours spent cooking (per week): self/wife'.
var label		SHOP_HUS 	'hours spent shopping (per week): self/husband'.
var label		SHOP_WIF 	'hours spent shopping (per week): self/wife'.
var label		laundHUS    	'hours spent cleaning clothes (per week): self/husband'.
var label		laundWIF     	'hours spent cleaning clothes (per week): self/wife'.
var label		clothHUS      	'hours making/mending clothes (per week): self/husband'.
var label		clothWIF     	'hours making/mending clothes (per week): self/wife'.
var label	          	WASH_HUS	'hours spent on laundry/cleaning home(/day): self/husband'.
var label	          	WASH_WIF 	'hours spent on laundry/cleaning home(/day): self/wife'.
var label		cleanHUS    	'hours spent cleaning home (per week): self/husband'.
var label		cleanWIF     	'hours spent cleaning home (per week): self/wife'.
var label		MIND_HUS   	'hours spent minding children (per week): self/husband'.
var label		MIND_WIF    	'hours spent minding children (per week): self/wife'.
var label		leisuHUS      	'hours spent on leisure (per week): self/husband'.
var label		leisuWIF      	'hours spent on leisure (per week): self/wife'.
breakd		hwrk_hus chorehus hwrk_wif chorewif by survey /cells mean.


*@ ATTITUDES.

if (sex=1)					atWroles	=	 	AT_ROLES.
if (sex=1)				 	atMroles	=	 	ATpROLES.
if (sex=0)					atMroles	=	 	AT_ROLES.
if (sex=0)					atWroles	=	 	ATpROLES.

var label					AT_DIV_D 	'Is heavy drinking sufficient for divorce?'.
var label					AT_DIV_V 	'Is domestic violence sufficient for divorce?'.
var label					AT_DIV_U 	'Is unfaithfulness sufficient for divorce?'.
val label					AT_DIV_D, AT_DIV_V, AT_DIV_U  1 'OK to divorce' 0 'not OK to divorce'.

var label	AT_jbSGL        'should an unmarried woman work outside home?'.
var label	AT_jbNoK         'should wife with no children work outside home?'.
var label	AT_jbInf     'should wife with preschool child work outside home?'.
var label	AT_jbKid   'should wife with schoolchild(ren) work outside home?'.
recode	   AT_jbSGL AT_jbNOK AT_jbINF AT_jbKID (1=2)(2=1)(3=0)(4=sysmis).			/* zzz does this apply to all surveys?.
val label AT_jbSGL AT_jbNOK AT_jbINF AT_jbKID 	2"full-time" 1"part-time" 0"not at all".


var label	at_h_out	"Dis/agree: it's justified for a man to hit his wife, if she goes out without telling him".
var label	at_hNegl	"Dis/agree: it's justified for a man to hit his wife, if she neglects the children".
var label	at_hArgu	"Dis/agree: it's justified for a man to hit his wife, if she argues with him".
var label	at_hNSex	"Dis/agree: it's justified for a man to hit his wife, if she refuses to have sex with him".
var label	at_hBurn	"Dis/agree: it's justified for a man to hit his wife, if she burns the food".
var label	at_hCook	"Dis/agree: it's justified for a man to hit his wife, if food is not cooked on time".
var label	at_hKeep	"Dis/agree: it's justified for a man to hit his wife, if she doesn't give him her earnings".
val lab		at_h_out,at_hNegl,at_hArgu,at_hNSex,at_hBurn,at_hKeep at_hCook 1"yes" 0"no".
* at_okHit is a Likert scale - so can't easily compare it with above zero/one variables.

* 'Anti-feminist' statements: .
var label	at_ROLES	                    "Dis/agree: Husb should earn/wife mind home".
var label	atpROLES	         "Spouse dis/agree: Husb should earn/wife mind home".
var label	atWroles	  "Woman/wife dis/agree: Husb should earn/wife mind home".
var label	atMroles	"Man/husband dis/agree: Husb should earn/wife mind home".
var label	at_shame	"Dis/agree: If a wife is unfaithful, it brings shame on her husband".
var label	at_okHit 	"Dis/agree: there are situations when it is justified for a man to hit his wife".
var label	at_pProb	"Dis/agree: if a woman earns more than her husband, it will cause problems".
var label	at_eProb	"Dis/agree: if a woman is more educated than her husband, it will cause problems".
var label	at_OBEY	"Dis/agree: A wife should always obey her husband".
var label	at_CANok 	"Dis/agree: It's better if meals made from raw (not prepared) ingredients".
var label	at_boost 	"Dis/agree: If husband loses job, wife should try to boost his confidence".
var label	at_allow 	"Dis/agree: I choose to let my spouse make decisions for the family".
var label	at_wAlow	"Dis/agree: women choose to let their spouse make decisions for the family".
var label	at_order	"Dis/agree: I want to make household decisions myself, without having to discuss it with my spouse".
var label	at_fight	"Dis/agree: it is shameful for a man to walk away from a fight".
var label	at_honor	"Dis/agree: it is very important for a man to protect the honour of himself and his family".
var label	at_putUp	"Dis/agree: A women should put up with a violent husband for her children".  /* New in 2017.
val lab    	at_roles,atpRoles,atMroles,atWroles,at_shame,at_okHIT,at_pProb,at_eProb,at_obey,at_CANok,at_boost,at_allow,at_wAlow,at_order,at_fight,at_honor, at_putUp
		1'agree strongly' 2'agree' 3'neither agree/disagree' 4'disagree' 5'disagree strongly'.
* Arguably, AT_allow & at_wAlow are vaguely feminist, if male respondent - depending on what decisions are meant (e.g. cooking?);
*  and at_letMe is antifeminist, if male respondent.

* 'Pro-feminist' statements: .
var label	at_consi   	 "Dis/agree: Husband should consider wife's opinion when making decision".
var label	at_wHAPY "Dis/agree: Woman happier if she has a job".
var label	at_oHAPY	 "Dis/agree: Family happier if woman has job".
var label	at_EqPay 	 "Do you agree with law to give women equal pay to men?".
var label	at_QUICK  	"Dis/agree: Prefer meals which can be prepared quickly".
var label	at_USEFL 	  "Dis/agree: Prepared food, e.g. cans, are very useful day-to-day".
var label	at_BUSY     	"Dis/agree: I am always short of time".
var label	at_PREPA  	"Dis/agree: Convenience foods can save time on cooking".
var label	at_decid    	"Dis/agree: Wife has the right to decide family expenditure".
var label	at_wJoin	   "Dis/agree: Wife may join social activity like religious gathering".
var label	at_w_say  	"Dis/agree: I wish women had more say in household decisions".
var label	at_letMe	  "Dis/agree: my spouse lets me make decisions for the family".
var label	at_noHit   	"Dis/agree: I am totally against violence".

* New to Indonesia 2001-2 (related to feminism, but in complicated ways).
var label	at_nKids	'How many children do you wish to have?'.
var label	at_nSons	'How many sons do you wish to have?'.
var label	at_nDaug	'How many daughters do you wish to have?'.
*var label	wantKids	'If you could go back to the time when you had no children, how many children would you want?'.	/* Use at_nKids instead.

* New to Kenya 2004: .
var label	at_Hobey	"Dis/agree: A husband should always obey his wife".
var label	at_chase	 "Dis/agree: During domestic violence, men often chase their wife away".

* At this point, all Likert scale variables use 1'totally agree' to 5'totally disagree'. 
* Convert variables with "pro-feminist" statements, so they use {high-score=feminist}, for women respondents.
recode        	at_consi,at_wHapy,at_oHapy,at_eqPay,at_quick,at_usefl,at_busy,at_prepa,at_decid,at_wJoin,at_w_say at_letMe at_noHit	at_sEarn	at_iEarn (1=5)(2=4)(3=3)(4=2)(5=1).
value label	at_consi,at_wHapy,at_oHapy,at_eqPay,at_quick,at_usefl,at_busy,at_prepa,at_decid,at_wJoin,at_w_say at_letMe at_noHit	at_sEarn	at_iEarn
		5'agree strongly' 4'agree' 3'neither agree/disagree' 2'disagree' 1'disagree strongly'.

* New to Nigeria 2005: .
var label	at_canDo 	"Is there anything a woman can do, to make husband spend less on alcohol etc?".
var label	at_CFhus 	"Do you [if male]/does your husband [if female] prefer car/drink/etc spending even if child hungry?".
var label	at_CFwif 	"Do you [if female]/does your wife [if male] prefer car/drink/etc spending even if child hungry?".
*var label	at_CFwif 	"Does your wife prefer car/drink/etc spending even if child hungry?".
*var label	at_CFhus 	"Does your husband prefer car/drink/etc spending even if child hungry?".
var label	at_CFmen 	"Do men prefer car/drink/etc spending even if child hungry?".
var label	at_cPray	'To cut his alcohol etc spending:  she should pray/they should pray together'.
var label	at_cLove	'To cut his alcohol etc spending:  show him respect/love/care, always be faithful'.
var label	at_cKids	'To cut his alcohol etc spending:  talk to husband on importance of children'.
var label	at_cAdvi	'To cut his alcohol etc spending:  advise; encourage him to save/be responsible'.
var label	at_cPlan	'To cut his alcohol etc spending:  share financial decisions/buy essentials'.
var label	at_cEarn	'To cut his alcohol etc spending:  she should support family financially'.
val label		at_canDo, at_CFwif,at_CFhus, at_CFmen at_cPray  to  at_cEarn	0'no' 1'yes'.

* New to Chad 2008: .
var label	at_letMe	"Dis/agree: 'My spouse lets me make decisions for the family' ".
var label	at_order	 "Dis/agree: 'I want to make decisions myself, without having to discuss it with my spouse' ".
var label	at_fight  	"Dis/agree: 'It is shameful for a man to  walk away from a fight' ".
var label	at_noHit	 "Dis/agree: 'I am totally against violence' ".
var label	at_honor	"Dis/agree: 'It is very important for a man to protect the honour of his family' ".

* New to Cameroon 2009: .
var label	at_mKids	"Dis/agree: 'A man should try to have as many children as he can' ".

* New to Congo-Brazzaville in 2011: .
var label	  at_sEarn	  "Dis/agree: 'A wife should earn money herself, and not totally depend on her husbands income' ".
var label	  at_iEarn	   "Dis/agree: 'I earn enough money to support everyone in this household' ".
var label   at_prote	  "Dis/agree: 'A wife usually obeys her husband in return for his protection' ".
var label   at_wantL	 "Dis/agree: 'I want to leave my husband due to GBV, but can't afford to' ".


*@ RELIGION.
recode  religion (93,94=50). /*I used 93='Koli (India)'	but	www.encyclopedia.com/article-1G2-1839300328/kolis.html (2Jan2015) state "They are primarily Hindu".
*                                           I used 94='Nepali (India)'; 86% Nepalis in DHS NP4 Hindu; "Nepal was until 2006 the only kingdom in the world to be offically Hindu": https://books.google.co.uk/books?id=v2yiyLLOj88C.
recode  religion (15=13).    /*	I used 15 for 'Christa do reino de Deus', but http://en.wikipedia.org/wiki/Universal_Church_of_the_Kingdom_of_God claims they are Pentecostal.
recode  religion (90=99).    /* This line is so I can use 95 for Mayan (in DHS surveys).
val label	religion 	                 		           	  0 'No religion/atheist/agnostic'	 10 'Christian (unspecified)'	 11 'Protestant'		12 'Presbyterian'	13 'Evangelical/Wesleyan/Baptist/Pentecostal' 	14 'Messianica'
                                                      		16 '7th Day Adventist'	   18 'Orthodox'		  19 'Roman Catholic' 	 	20 'Christian-related'	 	 21 'Rosicrucian'			22 'Mormon'  23 "Jehovah's Witness"  24 "Rastafari"
                                                     			30 'Muslim'	 31 'Bahai'  40 'Jewish/Zionist'		50 'Hindu/Vaisnavist'	 51 'Sikh'	52 'Kirat' 60 'Buddhist/neo-Buddhist'	61 'Jain'	70 'Parsi/Zoroastrian'  72 'Cao Dai'
                                                    				75 'Confucian'	80 'Animist'	81 'Traditional African' 82 'Independent African'	83 'Candomble'	84 'Umbanda'	89 'Spiritualist/Voodoo'	91 'Soicho-Noye (Brazil)' 92 'Teluja (India)'
                                                        95 'Mayan'  99 'unspecified religion'.
* Some values of religion (e.g. 31, 52, 72 and 75) aren't in WAS surveys; they are included for compatibility with DHS surveys.  I can't tell what "Teluja" means.
* 'Donyi polo' is a type of animism in Andhra Pradesh, and 'Sanamahi' a kind of Hinduism, according to Wikipedia (16th May 2010).
*crosstab	religion by live_cit.

*@ FAMILY STRUCTURE.
if       (fam_NGEN>2)   	                                   		fam_TYPE=5.
if       (famRELAT=0 and famINLAW=0) 		            fam_TYPE=1.
if       (sex=0 and famRELAT=1 & famINLAW=0) 	fam_TYPE=2.
if       (sex=1 and famRELAT=1 & famINLAW=0) 	fam_TYPE=3.
if       (sex=0 and famRELAT=0 & famINLAW=1) 	fam_TYPE=3.
if       (sex=0 and famRELAT=0 & famINLAW=1) 	fam_TYPE=2.
if       (famRELAT=1 and famINLAW=1) 	            	fam_TYPE=4.
recode	   fam_TYPE (5=sysmis).   /*One HH in BM92: not clear.
var label	  fam_TYPE 	'is the family nuclear, or extended?'.
val label	  fam_TYPE	1"nuclear/single person"  2"relatives of husband" 3"relatives of wife" 	4"both husb & wife relatives".
var label	  fam_NGEN  	'number of generations living in the HH'.
val label	  fam_NGEN 	1"one generation in HH" 	2"2 generations in HH"	3"3 generations in HH" 	4"4 generations in HH"   5"5 generations in HH".
var label	  famINlaw  	'Does the resp have any in-laws in the HH?'.
val label	  famINlaw 	0"no in-laws in hhold"  1"in-law(s) in hhold".
var label	 famRELAT 	'Does the resp have blood relatives in the HH?'.
val label	  famRELAT 	0"no relative in hhold" 1"relative(s) in hhold".

* For most WAS surveys, I know the age of each hhold member, but not WAS ZA.
if (INT_year=2000) n_age_0   =   mAGE_0     + fAGE_0.
if (INT_year=2000) n_age_1   =   mAGE_1     + fAGE_1.
if (INT_year=2000) n_age_2   =   mAGE_2     + fAGE_2.
if (INT_year=2000) n_age_3   =   mAGE_3     + fAGE_3.
*if(INT_year=2000) n_age_4   = ((mAGE_4_6 + fAGE_4_6) / 3).
*if(INT_year=2000) n_age_5   = ((mAGE_4_6 + fAGE_4_6) / 3).
*if(INT_year=2000) n_age_6   = ((mAGE_4_6 + fAGE_4_6) / 3).
*if(INT_year=2000) n_age_7   = ((mAGE_7_9 + fAGE_7_9) / 3).
*if(INT_year=2000) n_age_8   = ((mAGE_7_9 + fAGE_7_9) / 3).
*if(INT_year=2000) n_age_9   = ((mAGE_7_9 + fAGE_7_9) / 3).
*if(INT_year=2000) n_age_10 = ((mAGE1012 + fAGE1012) / 3).
*if(INT_year=2000) n_age_11 = ((mAGE1012 + fAGE1012) / 3).
*if(INT_year=2000) n_age_12 = ((mAGE1012 + fAGE1012) / 3).
*if(INT_year=2000) n_age_13 = ((mAGE1314 + fAGE1314) / 2).
*if(INT_year=2000) n_age_14 = ((mAGE1314 + fAGE1314) / 2).
*if(INT_year=2000) n_age_15 =   mAGE15     + fAGE15.
*if(INT_year=2000) n_age_16 = ((mAGE1618 + fAGE1618) / 3).
*if(INT_year=2000) n_age_17 = ((mAGE1618 + fAGE1618) / 3).
*if(INT_year=2000) n_age_18 = ((mAGE1618 + fAGE1618) / 3).
* Ensure the number in each age-group is a whole number.
if (INT_year=2000) n_age_4   = trunc((mAGE_4_6 + fAGE_4_6) / 3).
if (INT_year=2000) n_age_6   = trunc((mAGE_4_6 + fAGE_4_6) / 3).
if (INT_year=2000) n_age_5   =         (mAGE_4_6 + fAGE_4_6) - n_age_4   - n_age_6.
if (INT_year=2000) n_age_7   = trunc((mAGE_7_9 + fAGE_7_9) / 3).
if (INT_year=2000) n_age_9   = trunc((mAGE_7_9 + fAGE_7_9) / 3).
if (INT_year=2000) n_age_8   =         (mAGE_7_9 + fAGE_7_9) - n_age_7   - n_age_9.
if (INT_year=2000) n_age_10 = trunc((mAGE1012 + fAGE1012) / 3).
if (INT_year=2000) n_age_12 = trunc((mAGE1012 + fAGE1012) / 3).
if (INT_year=2000) n_age_11 =         (mAGE1012 + fAGE1012) - n_age_10 - n_age_12.
if (INT_year=2000) n_age_13 = trunc((mAGE1314 + fAGE1314) / 2).
if (INT_year=2000) n_age_14 =         (mAGE1314 + fAGE1314) - n_age_13.
if (INT_year=2000) n_age_15 =          mAGE15     + fAGE15.
if (INT_year=2000) n_age_16 = trunc((mAGE1618 + fAGE1618) / 3).
if (INT_year=2000) n_age_18 = trunc((mAGE1618 + fAGE1618) / 3).
if (INT_year=2000) n_age_17 =         (mAGE1618 + fAGE1618) - n_age_16 - n_age_18.
* The above syntax often puts two of the 4-to-6 agegroup as age 5, but none age 4 or 6;  correct this.
if (INT_year=2000 & n_age_5>1   & n_age_4=0)   n_age_45  = 2.
if (INT_year=2000                                           & n_age_45  = 2)     n_age_5 = n_age_5  - 1.
if (INT_year=2000                                           & n_age_45  = 2)     n_age_4 = n_age_4 + 1.
* Similarly for ages 7 to 9.
if (INT_year=2000 & n_age_8>1   & n_age_7=0)   n_age_78  = 2.
if (INT_year=2000                                           & n_age_78  = 2)     n_age_8 = n_age_8  - 1.
if (INT_year=2000                                           & n_age_78  = 2)     n_age_7 = n_age_7 + 1.
* Similarly for ages 10 to 12.
if (INT_year=2000 & n_age_11>1 & n_age_10=0) n_age_1011=2.
if (INT_year=2000                                           & n_age_1011=2)     n_age_11 = n_age_11  - 1.
if (INT_year=2000                                           & n_age_1011=2)     n_age_10 = n_age_10 + 1.
*if (INT_year=2000 & n_age_14>1 & n_age_13=0) n_age_1314=2. /* No cases of n_age_1314=2.
* Similarly for ages 16 to 18.
if (INT_year=2000 & n_age_17>1 & n_age_16=0) n_age_1617=2.
if (INT_year=2000                                           & n_age_1617=2)     n_age_17 = n_age_17  - 1.
if (INT_year=2000                                           & n_age_1617=2)     n_age_16 = n_age_16 + 1.
*.
if (INT_year=2000) n_age_dk = 0.
*cros     survey  by n_age_dk by sourcefile.

* Could define 'adult' as over 18 (arbitrary). 
*compute	N_CHILDR =  mAGE_0	+ mAGE_1  	+ mAGE_2  + mAGE_3	+ mAGE_4_6+mAGE_7_9+ mAGE1012+ mAGE1314+ mAGE15+ mAGE1618
                             	+  fAGE_0	+   fAGE_1  +   fAGE_2  	+   fAGE_3	+   fAGE_4_6+  fAGE_7_9+   fAGE1012+   fAGE1314+   fAGE15+   fAGE1618.
*compute	N_ADULTS = mAGE1924+ mAGE2534	+ mAGE35__			  +  fAGE1924+   fAGE2534+   fAGE35__ .
* Could define 'adult' as age 16+ (arbitrary):  I changed to this definition on 26th September 2009 (from 19+). 
*compute	N_CHILDR =  mAGE_0	+ mAGE_1  + mAGE_2  + mAGE_3	+ mAGE_4_6+mAGE_7_9	+ mAGE1012+ mAGE1314+ mAGE15
                             	+  fAGE_0	+   fAGE_1  +   fAGE_2 	+   fAGE_3	+   fAGE_4_6+  fAGE_7_9+   fAGE1012+   fAGE1314+   fAGE15.
*compute	N_ADULTS = mAGE1618 +  fAGE1618 + mAGE1924	+ mAGE2534	+ mAGE35__	+  fAGE1924+   fAGE2534+   fAGE35__ .
* From 27th September 2009, define adult as age 18 or older.
compute n_childr =n_age_0+n_age_1+n_age_2+n_age_3+n_age_4+n_age_5+n_age_6+n_age_7+n_age_8+n_age_9+n_age_10+n_age_11+n_age_12+n_age_13
									+n_age_14+n_age_15+n_age_16+n_age_17.
compute n_adults=n_age_18 + mAGE1924+ mAGE2534	+ mAGE35__ +  fAGE1924 +   fAGE2534 +   fAGE35__ + n_age_dk. /* Assume if unknown age, is adult.
compute n_male=mAGE_0+mAGE_1+mAGE_2+mAGE_3+mAGE_4_6+mAGE_7_9+mAGE1012+mAGE1314+mAGE15+mAGE1618+mAGE1924+mAGE2534
												         +mAGE35__ .
compute n_female=fAGE_0+  fAGE_1+  fAGE_2+  fAGE_3+  fAGE_4_6+  fAGE_7_9+  fAGE1012+fAGE1314+ fAGE15 +fAGE1618 +fAGE1924+ fAGE2534+fAGE35__ .
compute n_PEOPLE = N_ADULTS + N_CHILDR.
compute n_BABIES  =	  mAGE_0 +fAGE_0 +mAGE_1+fAGE_1 +mAGE_2 +fAGE_2 +mAGE_3 +fAGE_3.

var label		N_CHILDR 	'Number of children (age under 19) in the household'.
var label		N_ADULTS 	'Number of adults (age 19 or more) in the household'.
var label		N_PEOPLE	'Number of persons in the household'.
var label		N_MALE   	'Number of males (boys & men) in the household'.
var label		N_FEMALE	'Number of females (girls & women) in the household'.
var label		N_EARNER	'Number of people employed in the household'.
var label		mAge_0 	'Number of males in household, age 0'.
var label		mAge_1 	'Number of males in household, age 1'.
var label		mAge_2 	'Number of males in household, age 2'.
var label		mAge_3 	'Number of males in household, age 3'.
var label		mAge_4_6	'Number of males in household, age 4 to 6'.
var label		mAge_7_9	'Number of males in household, age 7 to 9'.
var label		mAge1012	'Number of males in household, age 10 to 12'.
var label		mAge1314	'Number of males in household, age 13 to 14'.
var label		mAge15 	'Number of males in household, age 15'.
var label		mAge1618	'Number of males in household, age 16 to 18'.
var label		mAge1924	'Number of males in household, age 19 to 24'.
var label		mAge2534	'Number of males in household, age 25 to 34'.
var label		mAge35__	'Number of males in household, age 35 or more'.
var label		fAge_0	'Number of females in household, age 0'.
var label		fAge_1	'Number of females in household, age 1'.
var label		fAge_2	'Number of females in household, age 2'.
var label		fAge_3	'Number of females in household, age 3'.
var label		fAge_4_6	'Number of females in household, age 4 to 6'.
var label		fAge_7_9	'Number of females in household, age 7 to 9'.
var label		fAge1012	'Number of females in household, age 10 to 12'.
var label		fAge1314	'Number of females in household, age 13 to 14'.
var label		fAge15	'Number of females in household, age 15'.
var label		fAge1618	'Number of females in household, age 16 to 18'.
var label		fAge1924	'Number of females in household, age 19 to 24'.
var label		fAge2534	'Number of females in household, age 25 to 34'.
var label		fAge35__	'Number of females in household, age 35 or more'.
var label		n_BABIES	'Number of children aged 0 to 3 in the HH'.
val label		n_BABIES	0"no child age under 4 in HHold".
* For BM92, I created n_INFANTS (age 4 to 5);  n_JUNIOR (age 6 to 11);  and n_SCHOOL (12 to 17). 
* But don't, now (they can't be derived from mAGE_4_6+AGE_4_6 etc; & my agebands are arbitrary).


* HH_equiv: my adaptation of methodology in Department of Social Security (1993), 'Households below average income: a statistical analysis 1979-1990/91'; 
* I use their "after housing costs" version, because housing costs are low in most "Third World" households.
* I use different agebands (e.g. age 4-6 rather 5-7) to DSS, because South African WAS data only has these agebands (age 4-6 etc).
if (N_ADULTS = 0)	HH_EQUIV = 0      .						/* This line added 31st Oct 2008.
if (N_ADULTS = 1)	HH_EQUIV = 0.55 .
if (N_ADULTS = 2)	HH_EQUIV = 1.00 .
if (N_ADULTS = 3)	HH_EQUIV = 1.45 .
if (N_ADULTS > 3)	HH_EQUIV = 1.45	+ ( 0.40 *( N_ADULTS - 3 )				  ).
*compute		HH_EQUIV = HH_EQUIV 	+ ( 0.07 *( mAge_0    + mAge_1 	+ fAge_0  + fAge_1 	) ).
*compute		HH_EQUIV = HH_EQUIV 	+ ( 0.18 *( mAge_2    + mAge_3 	+ fAge_2  + fAge_3 	) ).
*compute		HH_EQUIV = HH_EQUIV 	+ ( 0.21 *( mAge_4_6		+ fAge_4_6		) ).
*compute		HH_EQUIV = HH_EQUIV 	+ ( 0.23 *( mAge_7_9		+ fAge_7_9	 	) ).
*compute		HH_EQUIV = HH_EQUIV 	+ ( 0.26 *( mAge1012		+ fAge1012	 	) ).
*compute		HH_EQUIV = HH_EQUIV 	+ ( 0.28 *( mAge1314 +mAge15 	+ fAge1314 +fAge15	) ).
*compute		HH_EQUIV = HH_EQUIV 	+ ( 0.38 *( mAge1618		+ fAge1618		) ).
* The above 7 lines were used until 27th September 2009;  version below is slightly closer to the DSS definition.
compute		HH_EQUIV = HH_EQUIV 	+ ( 0.07 *( n_age_0    + n_age_1                    ) ).
compute		HH_EQUIV = HH_EQUIV 	+ ( 0.18 *( n_age_2    + n_age_3 	+ n_age_4 	 ) ).
compute		HH_EQUIV = HH_EQUIV 	+ ( 0.21 *( n_age_5	  	+ n_age_6  + n_age_7		 ) ).
compute		HH_EQUIV = HH_EQUIV 	+ ( 0.23 *( n_age_8		  + n_age_9  + n_age_10	) ).
compute		HH_EQUIV = HH_EQUIV 	+ ( 0.26 *( n_age_11		+ n_age_12	 	                ) ).
compute		HH_EQUIV = HH_EQUIV 	+ ( 0.28 *( n_age_13  + n_age_14 + n_age_15	) ).
compute		HH_EQUIV = HH_EQUIV 	+ ( 0.38 *( n_age_16		+ n_age_17                 		) ).
var label 		HH_EQUIV 'Household equivalence scale (calculated to create HHincEQI)'.
*freq		      HH_EQUIV.						/* There shouldn't be any zero values; but 50 cases are.
recode		   HH_EQUIV (0 = sysmis).
if (HHincome>0)  HHincEQI	= HHincome  	/ HH_EQUIV.

*breakd n_age_0 to n_age_18, n_adults by survey /cells mean.

* Work out calorie requirements, using info from WorldBank:  www.worldbank.org/html/prdph/lsms/country/pan97/docs/poveng.pdf, downloaded 15/11/2003, p.3.
* Figures below assume "moderate activity";  employed people use more calories, so could use job.  Male children, then female children, then adults.
*compute	ca_requi =  	(mage_0	*    738		) +
		(mage_1	*  1100		) +
		(mage_2	*  1300		) +
		(mage_3	*  1500		) +
	 	(mage_4_6	* (1500+1750+1750)/3	) +
		(mage_7_9	*  2000 		) +
		(mage1012	* (2200+2200+2350)/3	) +
		(mage1314	* (2350+2650)/2	) +
		(mage15	*  2650		) +
		(fage_0	*    738 		) +
		(fage_1	*  1100		) +
		(fage_2	*  1300		) +
		(fage_3 	*  1500 		) +
		(fage_4_6	* (1500+1600+1600)/3	) +
		(fage_7_9	*  1700		) +
		(fage1012	* (1900+1900+2000)/3	) +
		(fage1314	* (2000+2100)/2	) +
		(fage15	*  2100		) +
		(n_adults	* (3100+2100)/2	).
*Alternative version:  www.nutrition.org.uk/information/energyandnutrients/energy.html downloaded 21 Nov 2003.
*compute	ca_requi   =  	(age_0				 )	*(545+515+690+645+825+765+920+865)/8	+
				(age_1 + age_2 + age_3	 )	*(1230+1165)/2 		+
				(age_4 + age_5 + age_6	 )	*(1715+1545)/2 		+
				(age_7 + age_8 + age_9 + age10)	*(1970+1740)/2 		+
				(age11 + age12 + age13 + age14)	*(2220+1845)/2		+
				(age15		 )	*(2755+2110)/2		+
				(n_adults		 )	*(2550+1940)/2.
* Now more detailed versions, to assess if a wife can afford to leave her husband - assume she'd take young children with her; how old?.
*compute	pNrelat	= p1_relat.				/* Could only include (female) respondent's children, in list of people to take.
*.
recode		age_hus, age_wif (sysmis=999).		/* Temporary:  to reduce missing data, assume husb & wife age at least 24 (for ca_requi_u24).

compute		ca_requi_u24	= 0.
compute		ca_requi_u21	= 0.
compute		ca_requi_u18	= 0.
compute		ca_requi_u16	= 0.
compute		ca_requi 	= 0.
compute		proRequi 	= 0.
*.
compute	pNsex	= 1.
compute	pNage	= age_wif.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
if (age_wif>  0)		ca_requi_u24 	= cal_need.			/* Add calories for children below.
if (age_wif>  0)		ca_requi_u21 	= cal_need.			/* Add calories for children below.
if (age_wif>  0)		ca_requi_u18 	= cal_need.			/* Add calories for children below.
if (age_wif>  0)		ca_requi_u16 	= cal_need.			/* Add calories for children below.
if 	(age_wif<24)	ca_requi_u24	 = 0.
if 	(age_wif<21)	ca_requi_u21	 = 0.
if 	(age_wif<18)	ca_requi_u18	 = 0.
if 	(age_wif<16)	ca_requi_u16	 = 0.			/* If wife is young, don't count her calorie needs twice.
compute	         	ca_requi 	       = 0.
*.
compute	pNsex	= p1_sex.
compute	pNage	= p1_age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p2_sex.
compute	pNage	= p2_age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p3_sex.
compute	pNage	= p3_age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p4_sex.
compute	pNage	= p4_age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p5_sex.
compute	pNage	= p5_age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p6_sex.
compute	pNage	= p6_age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p7_sex.
compute	pNage	= p7_age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p8_sex.
compute	pNage	= p8_age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p9_sex.
compute	pNage	= p9_age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p10sex.
compute	pNage	= p10age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p11sex.
compute	pNage	= p11age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p12sex.
compute	pNage	= p12age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p13sex.
compute	pNage	= p13age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p14sex.
compute	pNage	= p14age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p15sex.
compute	pNage	= p15age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p16sex.
compute	pNage	= p16age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p17sex.
compute	pNage	= p17age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p18sex.
compute	pNage	= p18age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p19sex.
compute	pNage	= p19age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p20sex.
compute	pNage	= p20age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p21sex.
compute	pNage	= p21age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p22sex.
compute	pNage	= p22age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
compute	pNsex	= p23sex.
compute	pNage	= p23age.
include	'D:\_WAS\SPSS syntax for all years\calculate calorie need of 1 person.sps'.
*.
*if (survey = '2000 S. Africa')	ca_requi    =  	(mage_0	*    645.93			) +
			(mage_1	*    956.93			) +
			(mage_2	*  1148.32 			) +
			(mage_3	*  1339.71			) +
		 	(mage_4_6	* (1411.48+1483.25+1578.94)/3	) +
			(mage_7_9	* (1674.64+1746.41+1866.02)/3	) +
			(mage1012	* (1985.64+2105.26+2224.88)/3	) +
			(mage1314	* (2392.34+2535.88)/2		) +
			(mage15	*  2679.42			) +
			(fage_0 	*    598.08			) +
			(fage_1 	*    909.09			) +
			(fage_2 	*  1100.47			) +
			(fage_3 	*  1267.94			) +
			(fage_4_6	* (1315.78+1363.63+1459.33)/3	) +
			(fage_7_9	* (1555.02+1650.71+1746.41)/3	) +
			(fage1012	* (1818.18+1913.87+2033.49)/3	) +
			(fage1314	* (2129.18+2200.95)/2		) +
			(fage15   	*  2248.8			) +
			(n_adults	* (2822.96+2703.34+2488.03+2272.72 + 2296.65+2177.03+2081.33+1985.64)/8).
* Number aged 16-18: 	cal_need=2822.96, 2918.66, 2990.43;  2272.72, 2296.65, 2320.57 .
*if (survey = '2000 S. Africa')	ca_requi_u16=	(mage_0	*    645.93			) +
			(mage_1	*    956.93			) +
			(mage_2	*  1148.32 			) +
			(mage_3	*  1339.71			) +
		 	(mage_4_6	* (1411.48+1483.25+1578.94)/3	) +
			(mage_7_9	* (1674.64+1746.41+1866.02)/3	) +
			(mage1012	* (1985.64+2105.26+2224.88)/3	) +
			(mage1314	* (2392.34+2535.88)/2		) +
			(mage15	*  2679.42			) +
			(fage_0 	*    598.08			) +
			(fage_1 	*    909.09			) +
			(fage_2 	*  1100.47			) +
			(fage_3 	*  1267.94			) +
			(fage_4_6	* (1315.78+1363.63+1459.33)/3	) +
			(fage_7_9	* (1555.02+1650.71+1746.41)/3	) +
			(fage1012	* (1818.18+1913.87+2033.49)/3	) +
			(fage1314	* (2129.18+2200.95)/2		) +
			(fage15 	*  2248.8			) +
			(	  (2296.65+2177.03+2081.33+1985.64)/4 ).	/* Assume mum is an adult, but of unknown age (could I use age_wif?).
*if (survey = '2000 S. Africa')	ca_requi_u18 = ca_requi_u16.			/* ca_requi_u16 is correct;  ca_requi_u18 is underestimated.
*if (survey = '2000 S. Africa')	ca_requi_u21 = ca_requi_u16.			/* ca_requi_u16 is correct;  ca_requi_u21 is underestimated.
*if (survey = '2000 S. Africa')	ca_requi_u24 = ca_requi_u16.			/* ca_requi_u16 is correct;  ca_requi_u24 is underestimated.

* Protein requirements, from http://whqlibdoc.who.int/trs/WHO_TRS_935_eng.pdf table 47 (=p.244), downloaded 26 Sept 2009: .
*if (survey = '2000 S. Africa')	proRequi    =  	(mage_0	* 10.2   			) +
			(mage_1	 *   11.6			) +
			(mage_2	 *   11.9 			) +
			(mage_3	 *   13.1			) +
	 	(mage_4_6	* 17.1	) +
			(mage_7_9	* 25.9	) +
			(mage1012	* 40.5	) +
			(mage1314	* 40.5	) +
			(mage15	*     57.9	) +
			(fage_0 	*    	  9.4  ) +
			(fage_1 	*    	10.8		) +
			(fage_2 	*  			11.4  ) +
			(fage_3 	*  			12.7  ) +
			(fage_4_6	* 	 16.2 ) +
			(fage_7_9	*   26.2	) +
			(fage1012	* 	 41.0 ) +
			(fage1314	* 		41.0 ) +
			(fage15 	*  	  47.4 	) +
			(n_adults	*  (57.9 + 47.4)/2).
* Above block is an approximation to proRequi (in ZA).

* Alternative approach:  Assume boys & girls have similar protein requirements. 
* Protein requirements, from http://whqlibdoc.who.int/trs/WHO_TRS_935_eng.pdf table 47 (=p.244), downloaded 26 Sept 2009: .
*compute	proRequi    =  
  	(n_age_0	 * (10.2 +   9.4 )/2	) +
			(n_age_1	 * (11.6	+ 10.8	)/2	) +
			(n_age_2	 * (11.9 + 11.4 )/2	) +
			(n_age_3	 * (13.1	+ 12.7 )/2	) +
			(n_age_4	 * (17.1 + 16.2 )/2	) +
			(n_age_5	 * (17.1 + 16.2 )/2	) +
			(n_age_6	 * (17.1 + 16.2 )/2	) +
			(n_age_7 	* (25.9	+ 26.2	)/2 ) +
			(n_age_8 	* (25.9	+ 26.2	)/2 ) +
			(n_age_9 	* (25.9	+ 26.2	)/2 ) +
			(n_age_10* (25.9	+ 26.2	)/2 ) +
			(n_age_11* (40.5	+ 41.0	)/2 ) +
			(n_age_12* (40.5	+ 41.0	)/2 ) +
			(n_age_13* (40.5	+ 41.0	)/2 ) +
			(n_age_14* (40.5	+ 41.0	)/2 ) +
			(n_age_15* (57.9	+ 47.1 )/2 ) +
			(n_adults	 * (57.9 + 47.4 )/2 ).

if (pNsex=0 &  pNage=  0                     )  pro_need= 10.2 .
if (pNsex=0 &  pNage=  1                     )  pro_need= 11.6 .
if (pNsex=0 &  pNage=  2                     )  pro_need= 11.9 .
if (pNsex=0 &  pNage=  3                     )  pro_need= 13.1 .
if (pNsex=0 & (pNage>  3 & pNage<  7) )  pro_need= 17.1 .
if (pNsex=0 & (pNage>  6 & pNage<11) )  pro_need= 25.9 .
if (pNsex=0 & (pNage>10 & pNage<15) )  pro_need= 40.5 .
if (pNsex=0 & (pNage>14 & pNage<19) )  pro_need= 57.9 .
if (pNsex=0 &  pNage>18                     )  pro_need=    57.9 .  /* I can't see a figure for adults, so I assume same as 15-18.

if (pNsex=1 &  pNage=  0                     )  pro_need=   9.4 .
if (pNsex=1 &  pNage=  1                     )  pro_need= 10.8 .
if (pNsex=1 &  pNage=  2                     )  pro_need= 11.4 .
if (pNsex=1 &  pNage=  3                     )  pro_need= 12.7 .
if (pNsex=1 & (pNage>  3 & pNage<  7) )  pro_need= 16.2 .
if (pNsex=1 & (pNage>  6 & pNage<11) )  pro_need= 26.2 .
if (pNsex=1 & (pNage>10 & pNage<15) )  pro_need= 41.0 .
if (pNsex=1 & (pNage>14 & pNage<19) )  pro_need= 47.4 .
if (pNsex=1 &  pNage>18                     )  pro_need=    47.4 .  /* I can't see a figure for adults, so I assume same as 15-18.
*.
*freq	 	 ca_requi.								/* 45 cases of (ca_requi=0) - remove them.
*desc		 ca_requi ca_requi_u24 ca_requi_u21 ca_requi_u18 ca_requi_u16.
recode		 ca_requi ca_requi_u24 ca_requi_u21 ca_requi_u18 ca_requi_u16 (0=sysmis).
var lab		 ca_requi       	'Calories required: estimated from number & ages of household members'.
var lab		 ca_requi_u24	'Calories required: mum, and children in household age under 24'.
var lab		 ca_requi_u21	'Calories required: mum, and children in household age under 21'.
var lab		 ca_requi_u18	'Calories required: mum, and children in household age under 18'.
var lab		 ca_requi_u16	'Calories required: mum, and children in household age under 16'.
var lab		 proRequi       	'Protein required: estimated from number & ages of household members'.

*breakd		 ca_requi_u16 by survey /cells mean count.				/* This line useful to compare ZA with other countries.
*breakd		 ca_requi_u18 by survey /cells mean count.				/* This line useful to compare ZA with other countries.
*breakd		 ca_requi_u21 by survey /cells mean count.				/* This line useful to compare ZA with other countries.
*breakd		 ca_requi_u24 by survey /cells mean count.				/* This line useful to compare ZA with other countries.

recode		age_hus, age_wif (999 = sysmis).


*@ HOUSEHOLD FINANCIAL MANAGEMENT.
* SYSTEM TO IDENTIFY RELATION TO RESPONDENT: uses 3 dimensions. 
*	First digit is generation	 		(-100=child;  +100=parent;   etc);
*	second digit is sibling relationship 	( 010=sibling=brother/sister, etc);
*	the third digit is spouse 			( 001=respondent's spouse,  etc).
*Codes 801-803 are for mindKids; 2,3,4,etc for managMon,finalSay,at_final; other codes for p1_relat...p15relat.
value label	 p1_relat,p2_relat,p3_relat,p4_relat,p5_relat,p6_relat,p7_relat,p8_relat,p9_relat,p10relat,
		 p11relat,p12relat,p13relat,p14relat,p15relat,p16relat,p17relat,p18relat,p19relat,p20relat,
		 p21relat,p22relat,p23relat  MANAGmon,FINALsay,AT_final,MINDkids  HEALTsay,VISITsay,FOOD_say,CHILDsay finalH_m,finalW_m
	      200"Grandparent"			      210"Great-aunt/uncle"
	   201"Grandparent of spouse"
	      100"Parent"				      110"Aunt/uncle"
	   101"Parent of spouse"			   111"Aunt/uncle of spouse"
	102"Parent's spouse (step-parent)"
	      000"Respondent"			      010"Sibling"				030"Cousin"
	    001"Respondent's spouse"		    011"Sibling's spouse"  	021"Spouse's sibling"
											012"Brother/sister-in-law"
	    -100"Child" -103"adopted child"	     -110"Nephew/neice"
	  -101"Child of spouse"			  -121"Nephew/neice of spouse"
	-102"Child's spouse"
	    -200"Grandchild"			     -210"Great-nephew/neice"
	 -201"Grandchild of spouse"		   -221"Spouse's sib's grandchild"
										991 "head-of-household"
										992 "main earner"
	    -300"Great-grandchild"						993 "all in household"
										994 "self & other(s), e.g. self & child"
										995 "non-relative, e.g. friend or lodger"
										996 "other(s): unspecified"
										997 "other in-law;  or spouse & in-law(s)"
										998 "other relative(s)"
										999 "elders, e.g. parents"
										    1.1 "husband", 1.2 "wife"
										    2 "husband & wife together"
										    3 "husband & wife separately"
										    4 "husband's 2nd wife"
										    5 "other, not just husband & wife"
										801 "child's parents"
										802 "no children in hh" 
										803 "maid/baby-sitter"
										   -4 "Not in ID 2002 (data entry error)"
										   -3 "no earnings".
* If respondent is male, 'self' means man/husband;  if female, 'self' is woman/wife.
if (MANAGmon	=0 & sex=0) 	MANAGmon	= 1.1 .
if (MANAGmon	=0 & sex=1) 	MANAGmon	= 1.2 .
if (MANAGmon	=1 & sex=0) 	MANAGmon	= 1.2 .
if (MANAGmon	=1 & sex=1) 	MANAGmon	= 1.1 .
if (FINALsay	=0 & sex=0) 	FINALsay	= 1.1 .
if (FINALsay	=0 & sex=1) 	FINALsay	= 1.2 .
if (FINALsay	=1 & sex=0) 	FINALsay	= 1.2 .
if (FINALsay	=1 & sex=1) 	FINALsay	= 1.1 .
if (AT_FINAL	=0 & sex=0) 	AT_FINAL	= 1.1 .
if (AT_FINAL	=0 & sex=1) 	AT_FINAL	= 1.2 .
if (AT_FINAL	=1 & sex=0) 	AT_FINAL	= 1.2 .
if (AT_FINAL	=1 & sex=1) 	AT_FINAL	= 1.1 .
* If managMon is 'husb & wife separately' or 'husb & wife jointly' [or 'other'?] but respondent is single/widowed, treat as 'single husb' or 'single wife'.  
* However, only change this if there is just 1 adult in the household (the respondent may not be the head-of-household).
*crosstabs          managMon by married.
if (managMon=2 & sex=0 & (married=3 or married=4) & N_adults=1) 	managMon = 1.1.
if (managMon=2 & sex=1 & (married=3 or married=4) & N_adults=1) 	managMon = 1.2.
if (managMon=3 & sex=0 & (married=3 or married=4) & N_adults=1) 	managMon = 1.1.
if (managMon=3 & sex=1 & (married=3 or married=4) & N_adults=1) 	managMon = 1.2.
if (INT_year<>1994)	MANAGm_s					= MANAGmon.
if (INT_year<>1994)	    	        FINALs_s				= FINALsay.
if (INT_year<>1994)				AT_FIN_s		= AT_final.
if (INT_year<>1994)					    MINDki_s	= MINDkids.
recode			MANAGm_s, FINALs_s,	AT_FIN_s, MINDki_s          (1.1=0)(1.2, 4=1)(2, 3, 91=2)(else= -9).
val label			MANAGm_s, FINALs_s,	AT_FIN_s, MINDki_s   0"male" 1"female" 2"both males & females".
var label		MANAGmon	'Person who organises household money'.
var label		FINALsay	'Person with final say over household money'.
var label		AT_FINAL	'Who should have final say over HH money?'.
var label		MANAGm_s	'Sex of person organising household money'.
var label		FINALs_s	'Sex of person with final say over HH money'.
var label		AT_FIN_s	'Sex of who should have final say: HH money'.
var label		MINDki_s	'Sex of who minds children in the household'.


var label		bankResp 	"Does the respondent have a bank account (own, or joint account)?".
var label		bankSpou 	"Does the respondent's spouse have a bank account (own, or joint)?".
var label		bank_hus	"Does the husband have a bank account (own, or joint account)?".
var label		bank_wif	"Does the wife have a bank account (own, or joint account)?".
var label		bank_jnt	"Do respondent & spouse have a joint bank account?".
value label	 	bankResp bankSpou bank_hus bank_wif bank_jnt 	1'has account(s)' 
											0'does not have an account'.

* CONTROL asked in 2000 for the first time;  the precision (number of values used) varies between countries.
var label		CONTROL  "How much control do you have in household decisions?".
value label		CONTROL	    0 'no control'
					  15 'little control'
					  25   'some control'
					  35 'some control'
					  50 'equal control'
					  65 'a lot of control'
					  75   'most of the control'
					  85 'most of the control'
					100 'complete control'.	
*values 25 & 75 are for IN & NG & EG only; 15, 35, 65 & 85 only for other WAS surveys.

* New to Egypt 2006: .
value labels	TALKwork TALKplan TALKkids TALKmony TALKcomu 100"regularly" 50"sometimes" 0"never" -1"don't know" -2"no answer" -9"missing".
var label	TALKwork	"Does your spouse discuss work with you?".
var label	TALKplan	"Does your spouse discuss future plans with you?".
var label	TALKkids	"Does your spouse discuss your children's activities with you?".
var label	TALKmony	"Does your spouse discuss money with you?".
var label	TALKcomu	"Does your spouse discuss things that happen in the community with you?".


* Avoid leaving violence as missing data, if there were no arguments.
recode					                 violence     argument (sysmis= -33).
if (argument= 0 & violence  < 0)		violence 	= 0.
recode			                 		violence     argument (-33=sysmis).
*cros				                    	violence by argument.
if (viol_hit	 =0)	  	 	violence 	= 0.
if (violHitB	=0)		   	violence 	= 0.
if (viol_hit	 >0)	  	 	violence 	= 1.
if (violHitB	>0)		 	  violence 	= 1.
if (sex=1)				viol_hus		= viol_hit.
if (sex=0)				viol_hus		= violHitB.
if (sex=0)				viol_wif	 	= viol_hit.
if (sex=1)				viol_wif		 = violHitB.
recode         viol_wif      viol_hus     violence (-9 = sysmis).  /* This line is for India 2017.


if (sex=1 & survey<>'2005-6 Egypt')				vioR_hus		= vioM_hit.
if (sex=0 & survey<>'2005-6 Egypt')				vioR_hus		= vioMHitB.
if (sex=0 & survey<>'2005-6 Egypt')				vioR_wif		 = vioM_hit.
if (sex=1 & survey<>'2005-6 Egypt')				vioR_wif		 = vioMHitB.
* vioR (EG only) is similar to vioM (Chad and Cameroon); but they're not the same - EG is 6 months.
*.
if (sex=0)				violBhus	= violBeat.
if (sex=1)				violBwif		= violBeat.
*.
var label		  		argument	'Have you ever had an argument with your spouse?'.
var label 				violence		'Have these arguments led to violence between you?'.
var label				viol_hit		'Have you hit your partner?'.
var label				violHitB		'Have you been hit by your partner?'.
var label				vioMhitB	'Have you been hit by your partner, in the previous month?'.
var label				viol_hus		'Male respondent (or partner of female resp) experienced violence'.
var label				viol_wif		'Female respondent (or partner of male resp) experienced violence'.
var label				vioR_hus	'Male respondent (or partner of female resp) experienced violence in last month/6 months'.
var label				vioR_wif	'Female respondent (or partner of male resp) experienced violence in last month/6 months'.
var label				violBhus	'Male respondent (or partner of female resp) has been beaten'.
var label				violBwif		'Female respondent (or partner of male res) has been beaten'.
val label					argument,violence viol_hit,violHitB viol_hus,viol_wif vioR_wif violBhus,violBwif
					violBeat violHumi violThre violPush violSlap violPunc violKick violBurn violTkni violKnif violRape
					0'no' 0.5'yes: sometimes' 1'yes' 7.5'yes: often'.	/* Some of these value labels aren't used in Kenya.
var label	BusinWho	'Who is responsible for the family business?'.



*@ SPENDING.
*I add a few variables together below (e.g. sp_oilBr = sp_oil + sp_bread) to allow comparisons between WAS surveys.
if  (INT_year = 1992 or  INT_year=1997  or INT_year >2002)			 sp_oilBr 	= sp_oil	 	+ sp_bread.
if  (INT_year<>1994)		                            			 sp_br_mi	= sp_bread	+ sp_milk.	/*Only works on 2004.
if  (INT_year = 1994)				                            	 sp_bDair	= sp_br_mi	+ sp_chees.
if  (INT_year<>1994 &  INT_year<  2001)				 sp_bDair	= sp_bread	+ sp_dairy.
if  (survey<>'2005-6 Egypt')					                   sp_cereB	= sp_cerea 	+ sp_bread.
if  (INT_year < 2005 or INT_year = 2007)				 sp_mSnak	= sp_fMeal	+ sp_snack.
if  (INT_year<>1992 & INT_year<>1997 & sp_drink>-1 & sp_tobac>-1)		 sp_CigDr 	= sp_drink 	+ sp_tobac.
if  (survey<>'2005-6 Egypt')		                 			 sp_leisT	= sp_leisu	+ sp_cigDr.
* sp_leisu includes cigarettes in EG, but not in BR and ID WAS surveys;  add sp_leisu+sp_tobac (in WAS IN surveys), for comparability.
if  (sp_laund> -1) & (sp_maid>-1)				 sp_hHelp	= sp_laund	+ sp_maid.
* WAS Egypt combines 'utility' bills together:  it mentions electricity water & phone on the questionnaire, and I assume it also includes gas bills.
*breakd sp_leisu sp_leisT sp_cigdr sp_tobac sp_drink			by survey/cells mean.

*breakd sp_el_wa sp_elect sp_gas sp_phone sp_energ sp_water sp_utili		by survey/cells mean.
if  (INT_year = 2004)					                                                                        sp_el_wa	= sp_elect	+ sp_water.
if  (INT_year = 2004 or INT_year = 2007 or survey='2002 India' or survey='2012 India' or survey='2017 India')		 sp_utili	= sp_el_wa                                	+ sp_gas	+ sp_phone.
* It would be possible to combine water+electricity+gas (without phone) as 'utilities':  but in Kenya 2004, phone spending is big compared to gas+electricity.
*breakd   sp_house sp_housi sp_rent sp_energ sp_utili sp_el_wa	 sp_gas	 sp_phone sp_repai	 by survey /cells mean.
*desc 					      		   sp_housi 	                         sp_utili.	/* Some missing data.
if  (INT_year<>2000	  &  sp_housi>-1)                                                                         	                                	  sp_HOUSE	= sp_housi	+ sp_ENERG.
if  (INT_year<>2000	  &  sp_housi>-1 & sp_utili>-1)                                                              	                	  sp_HOUSE	= sp_housi	+ sp_utili.
* If we know both sp_utili and sp_energ, use sp_utili: it's usually bigger than sp_energ.
* In the above line, could assume sp_utili is (approximately) zero if sp_utili is missing:  it would slightly increase the sample size.
if  (survey='2002 India' or survey='2007 India' or survey='2012 India' or survey='2017 India') sp_HOUSE = sp_rent + sp_utili.
*if (survey='2002 India' or survey='2007 India')                                                          	                              sp_housi     = sp_rent.
if  (sp_repai>0)                                                                                                                              	                         sp_HOUSE = sp_HOUSE + sp_repai.  /* sp_repai is only in WAS Egypt, so far.

* Define SP_TOTAL and subtotals SP_FOOD, SP_ENERG in each WAS survey separately:  SP_TOTAL is usually the sum of each individual spending category in that
* survey, but sometimes (e.g. Egypt 2005-6) there's missing data - then, I use the total spending calculated by the organisation collecting the data (to avoid missing data).
* In some surveys (e.g. Nigeria), SP_ENERG includes sp_water;  if possible, exclude sp_water from SP_ENERG.
*compute		sp_nFOOD             = 	sp_TOTAL - sp_FOOD.
*if (sp_total<sp_food)	sp_nFOOD_check  = 	sp_TOTAL - sp_FOOD.
*breakd	    	sp_nFOOD_check	sp_TOTAL   sp_FOOD  by survey.	/*sp_nFOOD is sometimes negative in India 1992 & Egypt 2005, so don't use it.

*breakd sp_nFOOD sp_FOOD sp_HOUSE sp_maid sp_hHelp sp_TOTAL by survey /cells mean.
recode sp_hHelp (sysmis = -9).
if           (sp_hHelp= -9 & sp_maid>-9) sp_hHelp = sp_maid.
recode sp_hHelp ( -9 = sysmis).
* In 2008 Chad & 2009 Cameroon at least, sp_food is sometimes more than sp_total; both surveys asked respondents sp_TOTAL.
* If sp_FOOD+sp_HOUSE<sp_TOTAL, assume respondent added other spending categories not on q'naire.
* If sp_FOOD+sp_HOUSE>sp_TOTAL, assume respondent (or interviewer) added up items wrongly.
if (sp_FOOD + sp_HOUSE                         >sp_TOTAL) sp_TOTAL = sp_FOOD + sp_HOUSE.
if (sp_FOOD + sp_HOUSE + sp_hHelp >sp_TOTAL) sp_TOTAL = sp_FOOD + sp_HOUSE + sp_hHelp.                 /* As previous line;  sp_hHelp has some missing data.
*compute                                                       sp_sum                             = sp_FOOD + sp_HOUSE + sp_hHelp.
*corr                                                                 sp_sum         sp_TOTAL.

* This list is in the same order as the (/ PPP_now) list near the end of 'combine.sps'.
var label  sp_cerea	'HH spending (per month): cereals eg rice, corn, wheat flour'.
var label  sp_cereB	'HH spending (per month): cereals eg rice, flour;  bread'.
var label  sp_bread	'HH spending (per month): bread (& jam, in India)'.
var label  sp_veget	'HH spending (per month): vegetables/fruit'.
var label  sp_meatF 	'HH spending (per month): meat and fish'.
var label  sp_fish	'HH spending (per month): fish'.
var label  sp_meat	'HH spending (per month): meat'.
var label  sp_oil  	'HH spending (per month): cooking oil (& butter/margerine)'.
var label  sp_oilBr	'HH spending (per month): cooking oil, bread, jam, etc'.
var label  sp_dairy	'HH spending (per month): milk, dairy products, milk food drinks'.
var label  sp_br_mi	'HH spending (per month): bread & milk'.
var label  sp_chees	'HH spending (per month): cheese & dairy products except milk'.
var label  sp_BDair	'HH spending (per month): bread & dairy products'.
var label  sp_tuber	'HH spending (per month): tubers eg cassava, sweet potato, potato'.
var label  sp_grVeg	'HH spending (per month): green vegetables eg spinach'.
var label  sp_pulse	'HH spending (per month): beans/pulses/nuts, e.g. mung beans, tofu'.
var label  sp_fruit	'HH spending (per month): fruit'.
var label  sp_spice	'HH spending (per month): spices eg salt'.
var label  sp_insta	'HH spending (per month): instant foods (e.g. frozen, tinned)'.
var label  sp_Fmeal	'HH spending (per month): restaurant meals'.
var label  sp_mSnak	'HH spending (per month): restaurants & snacks'.
var label  sp_snack	'HH spending (per month): snacks from street-stalls'.
var label  sp_biscu	'HH spending (per month): biscuits, etc'.
var label  sp_ices 	'HH spending (per month): ice-creams'.
var label  sp_cofee	'HH spending (per month): coffee, tea, etc'.
var label  sp_other	'HH spending (per month): other provisions'.
var label  sp_FOOD	'HH spending (per month): ALL FOOD excluding restauraunts'.
var label  sp_gas  	'HH spending (per month): gas/kerosene'.
var label  sp_elect	'HH spending (per month): electricity'.
var label  sp_el_wa 	'HH spending (per month): electricity + water'.
var label  sp_ENERG	'HH spending (per month): gas+electricity'.				/* Often the same as sp_utili.
var label  sp_phone 	'HH spending (per month): telephone bill (including mobile)'.
var label  sp_utili 	'HH spending (per month): household utilities: electricity, gas, water, phone, etc'.
var label  sp_rent 	'HH spending (per month): house rent'.
var label  sp_mortg	'HH spending (per month): mortgage payment'.
var label  sp_housi 	'HH spending (per month): house rent or mortgage'.			/* Often the same as sp_rent.
var label  sp_loanR	'HH spending (per month): loan repayment'.				/* mortgage payment is with rent, not in sp_loanR.
var label  sp_repai	'HH spending (per month): house repairs'.
var label  sp_HOUSE	'HH spending (per month): RENT + GAS/ELECTRICITY/WATER'.
var label  sp_tobac	'HH spending (per month): tobacco'.
var label  sp_drink	'HH spending (per month): alcoholic drinks'.
var label  sp_CigDr	'HH spending (per month): tobacco + drink'.
var label  sp_gambl	'HH spending (per month): gambling, lottery'.
var label  sp_tFuel 	'HH spending (per month): fuel for car (& insurance)'.
var label  sp_trans 	'HH spending (per month): transport'.
var label  sp_cloth	'HH spending (per month): clothes/footwear inc repairs'.
var label  sp_clean	'HH spending (per month): cleaning products, eg detergent'.
var label  sp_toile	'HH spending (per month): personal toiletries'.
var label  sp_laund	'HH spending (per month): laundry services'.
var label  sp_maid 	'HH spending (per month): servant/maid'.
var label  sp_cCare	'HH spending (per month): child-care'.
var label  sp_hHelp	'HH spending (per month): laundry, maid (& child-care)'.
var label  sp_medic	'HH spending (per month): paid to hospital/doctor, medicine, etc'.
var label  sp_leisu	'HH spending (per month): recreation/entertainment'.
var label  sp_leisT	'HH spending (per month): recreation/entertainment + tobacco/alcohol'.
var label  sp_haird	'HH spending (per month): make-up & hairdressers'.
var label  sp_paper	'HH spending (per month): newspapers & magazines'.
var label  sp_cerem	'HH spending (per month): ceremonies/rituals, e.g. wedding'.
var label  sp_chari	'HH spending (per month): gifts to charities'.
var label  sp_holid	'HH spending (per month): travel/vacations (holidays)'.
var label  sp_furni	'HH spending (per month): furniture e.g. beds, sheets, towels'.
var label  sp_remit	'HH spending (per month): regular non-food gifts outside HH'.
var label  sp_educ	'HH spending (per month): education: school or college fees'.
var label  sp_lessn	'HH spending (per month): private lessons'.
var label  sp_tax		'HH spending (per month): tax, including property & vehicle'.
var label  sp_TOTAL 	'Total HH spending (per month)'.
*.
* Individual spending (only in WAS surveys after 2003, except sp_Hmeal & sp_Wmeal - which are only in bm92): .
var label  sp_Hmeal 	"Spending by husband/male respondent (per month):  restaurant meals".
var label  sp_Wmeal	    "Spending by wife/female respondent (per month):  restaurant meals".
var label  sp_Hdrnk	"Spending by husband/male respondent (per month):  alcohol".
var label  sp_Wdrnk	    "Spending by wife/female respondent (per month):  alcohol".
var label  sp_HClth	"Spending by husband/male respondent (per month):  clothes & shoes".
var label  sp_WClth	    "Spending by wife/female respondent (per month):  clothes & shoes".
var label  sp_HGamb	"Spending by husband/male respondent (per month):  lottery/gambling".
var label  sp_WGamb	    "Spending by wife/female respondent (per month):  lottery/gambling".
var label  sp_Hsoft	"Spending by husband/male respondent (per month):  soft drink".
var label  sp_Wsoft	    "Spending by wife/female respondent (per month):  soft drink".
var label  sp_Htoba	"Spending by husband/male respondent (per month):  tobacco etc".
var label  sp_Wtoba	    "Spending by wife/female respondent (per month):  tobacco etc".
var label  sp_Hcafe	"Spending by husband/male respondent (per month):  in cafes".		/* Egypt: "smoking (cigarettes, sheesha,cofeeshop etc)".
var label  sp_Wcafe	    "Spending by wife/female respondent (per month):  in cafes".		/* Egypt: "smoking (cigarettes, sheesha,cofeeshop etc)".
var label  sp_Hpers	"Spending by husband/male respondent (per month):  care e.g. haircut".
var label  sp_Wpers	    "Spending by wife/female respondent (per month):  care e.g. haircut".
var label  sp_Hmobi	"Spending by husband/male respondent (per month):  mobile phone".
var label  sp_Wmobi	    "Spending by wife/female respondent (per month):  mobile phone".
var label  sp_Hweb	"Spending by husband/male respondent (per month):  internet".
var label  sp_Wweb	    "Spending by wife/female respondent (per month):  internet".
var label  sp_Hremt	"Spending by husband/male respondent (per month):  to family outside hh".
var label  sp_Wremt	    "Spending by wife/female respondent (per month):  to family outside hh".
var label  sp_Hchar	"Spending by husband/male respondent (per month):  donations e.g. church".
var label  sp_Wchar	    "Spending by wife/female respondent (per month):  donations e.g. church".
var label  sp_Hcars	"Spending by husband/male respondent (per month):  transport equipment e.g. car".	/* Egypt only.
var label  sp_Wcars	    "Spending by wife/female respondent (per month):  transport equipment e.g. car".	/* Egypt only.
var label  sp_Hleis	"Spending by husband/male respondent (per month):  entertainment".			/* Egypt only.
var label  sp_Wleis	    "Spending by wife/female respondent (per month):  entertainment".			/* Egypt only.
var label  sp_HOthr	"Spending by husband/male respondent (per month):  other".				/* Egypt only.
var label  sp_WOthr	    "Spending by wife/female respondent (per month):  other".				/* Egypt only.
var label  SAVING   	'Household saving (per month)'.
*.
var label  earn_hus	"Earnings of husband after tax, per month".
var label  earn_wif	"Earnings of wife after tax, per month".
var label  earnResp	"Earnings of respondent after tax, per month".
var label  earnSpou	"Earnings of respondent's spouse after tax, per month".
var label  earnOthr	"Earnings of other household member(s) after tax, per month".
var label  HHincome	"Total household income, per month".
var label  HHincEQI	"Household equivalent income, per month: income, adjusted for number of people in household".


if (int_year<>1994 & sp_maid=0)	hireMaid=0.
if (int_year<>1994 & sp_maid>0)	hireMaid=1.
var label  				hireMaid  'Does the HH hire a full-time maid?'.
val label 	  			hireMaid 0"don't hire a fulltime maid" 	1"hire full-time maid"	2"2+ full-time maids".

var label		skipMeal  'Frequency of cutting meals in the last year'.
val labels		skipMeal 	0 'never'		1 'only 1 or 2 months' 	2 'some months, but not every month'	 3 'almost every month'.


*@ DURABLES OWNERSHIP.
*breakd  car by survey.
recode									TVcolour,TVbw (sysmis=-9).
if (INT_year<>1994  	& INT_year<>1997)	 			TVcolour	= -6.
if (INT_year<>1994  	& INT_year<>1997)				TVbw     	= -6.
if (TVbw = 0 or TVcolour = 0)						TV		=  0.  /* For 1994 & 1997 only.
if (TVbw > 0 or TVcolour > 0)						TV		=  1.  /* For 1994 & 1997 only.
if (		survey='2002 India'  &  sp_phone=0)			phone		=  0.
if (		survey='2002 India'  &  sp_phone>0)			phone		=  1.	/* Could be a mobile phone.
* Livestok is new to Egypt 2005.
if (cows=0    & 	goats=0)						livestok = 0.
if (cows=1)								livestok = 1.
if (		goats=1)						livestok = 1.

var label  CAR      		'Does the HH own a car?'.
var label  motorcyc		'Does the HH own a motorcycle/moped?'.
var label  bicycle		'Does the HH own a bicycle?'.
var label  TV       		'Does the HH own a television?'.
var label  TVcolour 		'Does the HH own a colour television?'.
var label  TVbw     		'Does the HH own a black-and-white television?'.
var label  TVbox 		'Does the HH own a set-top box, to use digital TV on a normal TV set?'.
var label  SATELITE		'Does the HH have satelite television (or cable TV)?'.
var label  VIDEO    		'Does the HH own a video-cassette player?'.
var label  Hi_Fi    		'Does the HH own a music system (hi-fi)?'.
var label  RADIO    		'Does the HH own a radio?'.
var label  COMPUTER 		'Does the HH own a computer?'.
var label  use_PC 		'Do you use a computer (including a laptop)?'.
var label  e_mail 		'Do you have e-mail address?'.
var label  INTERNET	 	'Does the HH have access to the internet on a home PC?'.
var label  PHONE    		'Is there a (fixed line) telephone in this house/flat?'.
var label  MOBILE   		'Does the HH own a mobile (cellular) phone?'.
var label  VACUUM   		'Does the household own a vacuum-cleaner?'.
var label  WASHMACH 		'Does the HH own a washing-machine?'.
var label  FRIDGE   		'Does the HH own a refrigerator (or fridge/freezer)?'.
var label  FOODPROC 		'Does the HH own an electric foodprocessor?'.
var label  WETGRIND 		'Does the HH own an electric food grinder?'.
var label  cookType 		'Type(s) of cooker the household owns'.
var label  presCook 		'Does the HH own a pressure-cooker?'.
var label  riceCook 		'Does the HH own a rice cooker?'.
var label  TOASTER	 	'Does the HH own an electric toaster?'.
var label  purifier 		'Does the HH own a water purifier/Reverse Osmosis system?'.
var label  MICROWVE 		'Does the HH own a microwave oven?'.
var label  fan 		'Does the HH own an electric fan?'.
var label  ELECTRIC 		'Is the home connected to electricity?'.
var label  generatr		'Does the HH own a electricity generator (for power cuts)?'.
var label  WATERtap 		'Water source for the household'.
var label  WATERhot 		'Is there hot water on tap in the home?'.
var label  TOILET   		'Is there a flush toilet/bathroom in the home?'.
var label  cows		'Does the HH own any cows?'.
var label  goats		'Does the HH own any goats?'.
var label  farmland		'Does the HH own any farmland?'.
var label  clock		'Household owns:  clock or watch'.
var label  bed		'Household owns:  bed'.
var label  videoDVD		'Household owns:  video and/or DVD'.
var label  sewMachi		'Household owns:  sewing machine'.
var label  air_cond		'Household owns:  air-conditioner'.
var label  purifier		'Household owns:  water purifier/Reverse Osmosis system'.
var label  truck		'Household owns:  truck, taxi, van, or bus'.
var label  livestok		'Household owns:  farm livestock'.
var label  farmEqip		'Household owns:  farm equipment'.
var label  secondHm		'Household owns:  commercial/residential building: not own home'.

val label		TV,TVcolour,TVbw,TVbox,satelite,video,Hi_Fi,radio,computer,e_mail,internet,mobile,
		vacuum,washMach,fridge,foodProc,wetGrind,presCook,riceCook,toaster,microwve,
		toilet generatr  motorcyc bicycle fan cows goats farmland
		0'do not own' 1'own' 2'own 2'  3'own 3'  4'own 4'  5'own 5'  6'own 6+'.
val label  car	0'do not own' 1'own' 2'own 2'  3'own 3'  4'own 4'  5'own 5'  6'own 6' 7'own 7' 8'own 8'.
val label  phone	0'no'   1'have a phone'   2 'have 2 phones'  -4'yes, but it is broken'.
val label  use_PC	0'no'   1'yes'.
val label  cookType lighting 0'none' 1'electric' 2'gas(/LPG)' 3'kerosene(/paraffin)' 4'firewood' 5'charcoal' 6'coal/lignite' 7'dung' 9'solar'  11'electric & gas' 12'electric & kerosene'
		 13'gas & kerosene' 14'electric & gas & kerosene'  
		  99'cooker (unspecified)'  1.5'gas or electric' 2.5'electric or gas, and kerosene'. /* These labels are for Nigeria: cooker may be gas OR electric.

* For Kenya 2004, I use cookType value labels for lighting also.
var label Lighting 	'Main source of lighting'.
val label ELECTRIC	0'not connected' 1'connected' 2'connected but not switched on'.


val label  WATERhot	   0 'do not have a hot water tap' 	   1'hot water tap(s) in home'.
val label  WATERtap	   0 'do not have a water tap'
		  10 'from stream/river/canal'		15 'from spring'				20 'rain water'
		  30 'other: unspecified'
		  40 	  'open public well: no pump'	41	 'open public well (dk if pump)'	42	 'open public well: pump'
		  45 	 'open private well: no pump'	46	'open private well (dk if pump)'	47	'open private well: pump'
		  50  'protected public well: no pump'	51   'protected public well (dk if pump)'	52   'protected public well: pump'
		  55 'protected private well: no pump'	56  'protected private well (dk if pump)'	57  'protected private well: pump'
		  70 'buy water'				80 'bottled mineral water'
		  90 'tap in the street'		  	95 'tap in the yard/plot'			100 'tap in home'.

val label  TOILET	0'no' 0.5'toilet outside, e.g. pit' 0.8'traditional bucket flush toilet' 0.9'traditional tank flush toilet' 1'toilet in the house'
			2'have 2 toilets'  3'have 3 toilets'  4'have 4 toilets'  5'have 5 toilets'  6'have 6+ toilets'.


*@ TYPE OF ACCOMMODATION.
var label 		homeType 'is respondent a slum/street-dweller?'.
val label 		homeType
val label 		homeType
			    0 	"street-dweller"
			  10	"self-built shack: temporary (kuchcha jhuggi)"
		 	  20	"self-built shack: permanent (pucca jhuggi)"
		 	  25	"self-built shack in a backyard"
			  30	"home surrounded by animal waste/puddles/refuse/stable"
			  40	"cortico (tenement) dweller"
		 	  43	"garage/ modified garage/ rooms in the back"
		 	  45	"traditional hut"
		 	  46	"Rondavel/ Zozo hut"
			  50	"other: unspecified"
		 	  55	"caravan or mobile home"
			  56	"single room"
			  58	"two rooms"
			  59	"simple wooden house"
		 	  60	"roomed house (RDP house), or room+parlour"
		 	  61	"matchbox type house or 51/9 (3-4 rooms): separate stand/yard"
		 	  63	"improved matchbox house on separate stand/yard, or mini-flat"
			  70	"simple cement house"
		 	  80	"part of a house/ share a house"
		 	  84	"granny flat on this property/ flatlet"
		 	  85	"second house/ cottage on this property"
		 	  90	"a unit in a block of flats"
		 	  97	"semi-detached or joint house"
		 	  98	"townhouse or cluster house in complex"
		 	  99	"suburban type house (2 or more bedrooms, inside bathroom)"
			100	"OK house/apartment".
* High score is OK house: my estimate.  Could be systematic, eg: permanent? waterproof? water supply?.
* Hard to match to Indonesia data - which has many variables.
* India 2002 qnaire has 'self-built home'=1:  I meant a normal home, but it could be interpreted as shack.
* Could use phone to identify if home is permanent?  - but some phones are mobile/cellphones.

* I created a new system to classify building materials, where a higher score means less permanent.  'Masonry' is a vague term.
value label		homeFlor   homeWall	homeRoof		  0'carpet/vinyl/parquet or polished wood'
	  1'concrete'			  2'ceramic/marble/granite/stone'   3'(red) brick & cement'		  4'masonry (concrete/stone/etc)'
	  5'asbestos cement'		  6'cement/tiles/terazzo'		  7'roof tiles'			  8'zinc sheets'
	  9'iron sheets'			10'hardwood/board/plywood'	11'bamboo/plaited bamboo slats'	12'grass thatch'
	13'foliage/palm leaves'		14'soil/dirt/mud'							 -4'other'.
* Make an aproximation for surveys in which homeWall & homeRoof aren't known.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=10)						homeWall = 10.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=20 or homeType=25)				homeWall =   9.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=45 or homeType=46)				homeWall = 14.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=60 or homeType=61 or homeType=63)			homeWall =   3.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=80 or homeType=84 or homeType=85)			homeWall =   3.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=40 or homeType=90)				homeWall =   1.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=97 or homeType=98 or homeType=99 or homeType=100)	homeWall =   3.
* In S.Africa, I think 'matchbox house' & 'RDP house' both have brick walls & tin roof.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=10)						homeRoof = 13.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=20 or homeType=25)				homeRoof =   9.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=45 or homeType=46)				homeRoof = 12.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=60 or homeType=61 or homeType=63)			homeRoof =   9.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=80 or homeType=84 or homeType=85)			homeRoof =   7.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=40 or homeType=90)				homeRoof =   4.
if (int_year<2001 or live_cit<7 or int_year=2003 or int_year=2005) & (homeType=97 or homeType=98 or homeType=99 or homeType=100)	homeRoof =   7.
* Could also estimate homeFlor, using homeType.
var lab					homeWall	'Building materials used to build home:  walls'.
var lab					homeRoof	'Building materials used to build home:  roof'.
var lab					homeFlor	'Building materials used to build home:  floor'.

var labels		tenure 'Home is owned or rented'.
val labels		tenure 	100'self owned' 90'owned jointly' 80'owned by family member' 70'buying on mortgage' 
			  50'other: unspecified' 30'rented (contracted)'  20'not self-owned, but no rent paid'.



Document   'Work, Attitudes & Spending in India, Brazil, South Africa, Indonesia, Nigeria, Kenya & Egypt':
  This SPSS dataset combines data from the following household surveys:
    1992 survey:  Bombay and Madras		  	urban	India      		(IMRB);
    1994 survey:  Rio de Janeiro & Sao Paulo			urban	Brazil		(Marplan);
    1997 survey:  Bombay, Madras, Delhi, Calcutta		urban	India          		(IMRB);
    2000 survey:  eleven cities				urban	South Africa		(Markinor)
    2001 survey:  Palembang,Jakarta,Bandung,Surabaya		urban	Indonesia		(Univ.Indonesia);
    2002 survey:  Palembang,Jakarta,Bandung,Surabaya		urban	Indonesia		(Univ.Indonesia);
    2002 survey:  Bombay,Madras,Delhi,Calcutta,Kerala,Patna		urban	India          		(IMRB);
    2003 survey:	 37 locations			urban+rural	Nigeria		(RMS);
    2004 survey:	 44 locations			urban+rural	Kenya		(SBO);
    2005 survey:	 37 locations			urban+rural	Nigeria		(RMS);
    2005 survey:  seven governorates				urban+rural	Egypt		(Cairo University);
    2007 survey:  11 cities				urban	India          		(IMRB);
    2008 survey:  some but not all regions (some unsafe, due to insurgents)	urban+rural	Chad		(Cible);
    2009 survey:  all regions				urban+rural	Cameroon		(Cible);
    2011 survey:   several regions				urban+rural	Congo-Brazzaville 	(Cible);
    2012 survey:  11 cities				urban	India          		(IMRB)
    2017 survey:  11 cities				urban	India          		(IMRB)
 All were commissioned by John Simister, Economics & International Business Dept, Manchester Metropolitan University, UK;
 Fieldwork was carried out by the Indian Market Research Bureau Ltd;  Marplan Brasil ltda.; Markinor Pty Ltd.;  University of Indonesia;  Research & Marketing Services Ltd;
 SBO Research Ltd (formerly called Strategic Business Opportunities Ltd);  CSSA: FEPS, University of Cairo;  Cible Ltd.
 The data was thoroughly checked by John Simister, and some new variables calculated, before being deposited (with machine-readable documentation) at the ESRC Data
 Archive (University of Essex, UK).   See the SPSS syntax files for more information on variables included in the dataset, and how derived variables were created. &
 +
 The 1992 data was deposited earlier at the UK Data Archive (study SN:3290); I call it 'bm92'.
 For each variable in this dataset, I feel that variable is comparable between different surveys, except the following differences between bm92 & this dataset:
   *	In bm92, time-use variables COOK_HUS, COOK_WIF, WASH_HUS, & WASH_WIF were in hours PER DAY (in this dataset, time-use is in hours per week);
   *	In bm92, country-of-birth codes (for people born outside India) were not internet country codes (which this survey uses). &
 +
 There are important differences between the sample frame for these surveys;
 hence comparisons between countries should be used with caution.  The
 BM92 and RS94 surveys were based on a random survey of households,  so
 each sample is representative of the cities studied.   However, the BMDC97
 sample was limited to married couples  (to increase the number of couples:
 WAS surveys were intended to study wives control over household spending);
 SA2000 includes 2,000 urban and 1,500 rural households, but most questions
 were not asked of the rural subsample. &
 +
 The India (1997) survey was written in English, and (where necessary) IMRB
 interviewers translated each question to language of the respondent - shown
 in variable INT_LANG.  The Brazil (1994) questionnaire was translated from
 English to Portuguese, by Marplan Brasil;  all interviews were carried out
 in Portuguese. Documentation files for this dataset include the Portuguese
 version of the questionnaire (as used in the actual survey, but retyped by
 John Simister), as well as a translation from Portuguese back into English.  The
 The SA2000 survey was written in English and translated by the interviewer
 where necessary.  The 2001 Indonesian survey is in Bahasa Indonesian. &
 +
 I am grateful to the employees at the organisations which carried out fieldwork;
 their advice on improving the questionnaire was very helpful - I am especially
 grateful to Virginia Silva e Silva (Marplan Brasil);  Anneke Greyling (Markinor);
 Wiyono Nur Hadi & Hendro Hendratno (University of Indonesia);
 Mariam Fagbemi (RMS);  Peninnah Mukiri (SBO);  and Fatma El Zanaty (Cairo University). &
                                                                                        John Simister, March 2017.
*END DOCUMENT.

